require "temboo"

module Mixpanel




  module DataExport




    module Events



      ##############################################################################
      #
      # EventData
      #
      # Gets unique, total, or average data for a set of events over the last N days, weeks, or months.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class EventData < Choreography

        ####
        #  Create a new instance of the EventData Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Events/EventData")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return EventDataInputSet
        ####
        def new_input_set()
          return EventDataInputSet.new()
        end

        def make_result_set()
          return EventDataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = EventDataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the EventData
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class EventDataInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventNames input for this Choreo. 
          # 
          # @param String - (required, json) A JSON array containing the event or events you wish to get data for.
          ###

          def set_EventNames(value)
            set_input("EventNames", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Interval input for this Choreo. 
          # 
          # @param Integer - (required, integer) The time interval to return. This relates to the value provided for Unit.
          ###

          def set_Interval(value)
            set_input("Interval", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and csv.
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (required, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (required, string) The granularity of the data to return. Valid values are: minute, hour, day, week, or month.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the EventData Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class EventDataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class EventData



      ##############################################################################
      #
      # TopEvents
      #
      # Gets the top events for today, with their counts and the normalized percent change from yesterday.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class TopEvents < Choreography

        ####
        #  Create a new instance of the TopEvents Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Events/TopEvents")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return TopEventsInputSet
        ####
        def new_input_set()
          return TopEventsInputSet.new()
        end

        def make_result_set()
          return TopEventsResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = TopEventsResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the TopEvents
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class TopEventsInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The maximum number of events to return. Defaults to 100 (the max the limit).
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (required, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the TopEvents Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class TopEventsResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class TopEvents



      ##############################################################################
      #
      # TopNames
      #
      # Gets a list of the most common events over the last 31 days.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class TopNames < Choreography

        ####
        #  Create a new instance of the TopNames Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Events/TopNames")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return TopNamesInputSet
        ####
        def new_input_set()
          return TopNamesInputSet.new()
        end

        def make_result_set()
          return TopNamesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = TopNamesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the TopNames
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class TopNamesInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The maximum number of events to return. Defaults to 100 (the max the limit).
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (required, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the TopNames Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class TopNamesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class TopNames




    end # module Events

    module Funnels



      ##############################################################################
      #
      # FunnelData
      #
      # Gets data for a specified funnel.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class FunnelData < Choreography

        ####
        #  Create a new instance of the FunnelData Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Funnels/FunnelData")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return FunnelDataInputSet
        ####
        def new_input_set()
          return FunnelDataInputSet.new()
        end

        def make_result_set()
          return FunnelDataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = FunnelDataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the FunnelData
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class FunnelDataInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (optional, date) The first date in yyyy-mm-dd format from which a user can begin the first step in the funnel. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the FunnelID input for this Choreo. 
          # 
          # @param String - (required, string) The ID of the funnel to get data for.
          ###

          def set_FunnelID(value)
            set_input("FunnelID", value)
          end
          #### 
          # Set the value of the Interval input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of days you want your results bucketed into.The default value is 1.
          ###

          def set_Interval(value)
            set_input("Interval", value)
          end
          #### 
          # Set the value of the Length input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of days each user has to complete the funnel, starting from the time they triggered the first step in the funnel. May not be greater than 60 days. Defaults to 14.
          ###

          def set_Length(value)
            set_input("Length", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Return the top limit property values. This parameter is ignored if the On input is not specified.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (optional, string) The property expression to segment the event on (e.g., properties["Referred By"] == "Friend"). See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (optional, date) The last date in yyyy-mm-dd format from which a user can begin the first step in the funnel. This date is inclusive. The date range may not be more than 60 days.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) This is an alternate way of specifying interval and can set to be 'day' or 'week'.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., properties["Signed Up"]). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the FunnelData Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class FunnelDataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class FunnelData



      ##############################################################################
      #
      # FunnelList
      #
      # Gets the names and funnel_ids of your funnels.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class FunnelList < Choreography

        ####
        #  Create a new instance of the FunnelList Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Funnels/FunnelList")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return FunnelListInputSet
        ####
        def new_input_set()
          return FunnelListInputSet.new()
        end

        def make_result_set()
          return FunnelListResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = FunnelListResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the FunnelList
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class FunnelListInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the FunnelList Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class FunnelListResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class FunnelList




    end # module Funnels

    module People



      ##############################################################################
      #
      # Engage
      #
      # Queries Mixpanel for data about people.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class Engage < Choreography

        ####
        #  Create a new instance of the Engage Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/People/Engage")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return EngageInputSet
        ####
        def new_input_set()
          return EngageInputSet.new()
        end

        def make_result_set()
          return EngageResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = EngageResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the Engage
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class EngageInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Page input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Which page of the results to retrieve. Pages start at zero. If the "page" parameter is provided, the session_id parameter must also be provided.
          ###

          def set_Page(value)
            set_input("Page", value)
          end
          #### 
          # Set the value of the SessionID input for this Choreo. 
          # 
          # @param String - (optional, string) A string id provided in the results of a previous query. Using a session_id speeds up api response, and allows paging through results.
          ###

          def set_SessionID(value)
            set_input("SessionID", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter people by (e.g., properties["time"]). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the Engage Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class EngageResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class Engage




    end # module People

    module Properties



      ##############################################################################
      #
      # PropertyData
      #
      # Gets unique, total, or average data for of a single event and property over the last N days, weeks, or months.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class PropertyData < Choreography

        ####
        #  Create a new instance of the PropertyData Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Properties/PropertyData")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return PropertyDataInputSet
        ####
        def new_input_set()
          return PropertyDataInputSet.new()
        end

        def make_result_set()
          return PropertyDataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = PropertyDataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the PropertyData
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class PropertyDataInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The name of the event that you wish to get data for.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Interval input for this Choreo. 
          # 
          # @param Integer - (required, integer) The time interval to return. This relates to the value provided for Unit.
          ###

          def set_Interval(value)
            set_input("Interval", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The maximum number of values to return. Defaults to 255.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the PropertyName input for this Choreo. 
          # 
          # @param String - (required, string) The name of the property you would like to get data for.
          ###

          def set_PropertyName(value)
            set_input("PropertyName", value)
          end
          #### 
          # Set the value of the PropertyValues input for this Choreo. 
          # 
          # @param String - (optional, json) A JSON array containing property values that you wish to retrieve.
          ###

          def set_PropertyValues(value)
            set_input("PropertyValues", value)
          end
          #### 
          # Set the value of the ResponseFormat input for this Choreo. 
          # 
          # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and csv.
          ###

          def set_ResponseFormat(value)
            set_input("ResponseFormat", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (required, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (required, string) The granularity of the data to return. Valid values are: minute, hour, day, week, or month.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the PropertyData Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class PropertyDataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class PropertyData



      ##############################################################################
      #
      # TopProperties
      #
      # Gets the top property names for an event.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class TopProperties < Choreography

        ####
        #  Create a new instance of the TopProperties Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Properties/TopProperties")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return TopPropertiesInputSet
        ####
        def new_input_set()
          return TopPropertiesInputSet.new()
        end

        def make_result_set()
          return TopPropertiesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = TopPropertiesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the TopProperties
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class TopPropertiesInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The name of the event that you wish to get data for.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The maximum number of properties to return. Defaults to 10.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the TopProperties Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class TopPropertiesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class TopProperties



      ##############################################################################
      #
      # TopValues
      #
      # Gets the top values for a property.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class TopValues < Choreography

        ####
        #  Create a new instance of the TopValues Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Properties/TopValues")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return TopValuesInputSet
        ####
        def new_input_set()
          return TopValuesInputSet.new()
        end

        def make_result_set()
          return TopValuesResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = TopValuesResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the TopValues
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class TopValuesInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The name of the event that you wish to get data for.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The maximum number of values to return. Defaults to 255.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the PropertyName input for this Choreo. 
          # 
          # @param String - (required, string) The name of the property you would like to get data for.
          ###

          def set_PropertyName(value)
            set_input("PropertyName", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the TopValues Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class TopValuesResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class TopValues




    end # module Properties

    module Retention



      ##############################################################################
      #
      # RetentionData
      #
      # Gets cohort analysis.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class RetentionData < Choreography

        ####
        #  Create a new instance of the RetentionData Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Retention/RetentionData")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RetentionDataInputSet
        ####
        def new_input_set()
          return RetentionDataInputSet.new()
        end

        def make_result_set()
          return RetentionDataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RetentionDataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the RetentionData
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RetentionDataInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the BornEvent input for this Choreo. 
          # 
          # @param String - (conditional, string) The first event a user must do to be counted in a birth retention cohort. Required when retention_type is 'birth'.
          ###

          def set_BornEvent(value)
            set_input("BornEvent", value)
          end
          #### 
          # Set the value of the BornWhere input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter born_events by. See Choreo description for examples.
          ###

          def set_BornWhere(value)
            set_input("BornWhere", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (optional, string) The event to generate returning counts for.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to begin generating cohorts from. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the Interval input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of days you want your results bucketed into.The default value is 1 or specified by unit.
          ###

          def set_Interval(value)
            set_input("Interval", value)
          end
          #### 
          # Set the value of the IntervalCount input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The number of intervals you want. Defaults to 1.
          ###

          def set_IntervalCount(value)
            set_input("IntervalCount", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Return the top limit segmentation values. This parameter is ignored if the On input is not specified.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (optional, string) The property expression to segment the second event on. See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the RetentionType input for this Choreo. 
          # 
          # @param String - (conditional, string) The type of retention. Valid values are: birth (the default) or compounded.
          ###

          def set_RetentionType(value)
            set_input("RetentionType", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to stop generating cohorts from. This date is inclusive.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) This is an alternate way of specifying interval. Valid values are: day, week, or month.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., properties["Signed Up"]). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the RetentionData Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RetentionDataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class RetentionData




    end # module Retention

    module Segmentation



      ##############################################################################
      #
      # Average
      #
      # Averages an expression for events per unit time.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class Average < Choreography

        ####
        #  Create a new instance of the Average Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Segmentation/Average")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return AverageInputSet
        ####
        def new_input_set()
          return AverageInputSet.new()
        end

        def make_result_set()
          return AverageResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = AverageResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the Average
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class AverageInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The event that you wish to segment on.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to begin querying for the event from. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (required, string) The expression to average per unit time. The result of the expression should be a numeric value (e.g., properties["time"]. See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to stop querying for the event from. This date is inclusive. The date range may not be more than 30 days.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) Determines the buckets into which the property values that you segment on are placed. Valid values are: hour or day.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., properties["time"] >= 2000). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the Average Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class AverageResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class Average



      ##############################################################################
      #
      # Numeric
      #
      # Gets data for an event, segmented and filtered by properties, with values placed into numeric buckets.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class Numeric < Choreography

        ####
        #  Create a new instance of the Numeric Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Segmentation/Numeric")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return NumericInputSet
        ####
        def new_input_set()
          return NumericInputSet.new()
        end

        def make_result_set()
          return NumericResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = NumericResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the Numeric
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class NumericInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the Buckets input for this Choreo. 
          # 
          # @param Integer - (required, integer) The number of buckets that you wish to divide the numeric values up into. Bucket ranges are automatically computed based on the maximum and minimum of the 'On' expression.
          ###

          def set_Buckets(value)
            set_input("Buckets", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The event that you wish to segment on.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to begin querying for the event from. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (required, string) The property expression to segment the event on. Must be a numeric expression (e.g., number(properties["time"]). See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to stop querying for the event from. This date is inclusive.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (optional, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) Determines the buckets into which the property values that you segment on are placed. Valid values are: hour or day.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., number(properties["time"]) >= 2000). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the Numeric Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class NumericResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class Numeric



      ##############################################################################
      #
      # SegmentationData
      #
      # Gets data for an event, segmented and filtered by properties.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class SegmentationData < Choreography

        ####
        #  Create a new instance of the SegmentationData Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Segmentation/SegmentationData")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return SegmentationDataInputSet
        ####
        def new_input_set()
          return SegmentationDataInputSet.new()
        end

        def make_result_set()
          return SegmentationDataResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = SegmentationDataResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the SegmentationData
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class SegmentationDataInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The event that you wish to segment on.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to begin querying for the event from. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the Limit input for this Choreo. 
          # 
          # @param Integer - (optional, integer) Return the top limit property values. This parameter is ignored if the On input is not specified.
          ###

          def set_Limit(value)
            set_input("Limit", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (optional, string) The property expression to segment the event on (e.g., properties["Referred By"] == "Friend"). See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to stop querying for the event from. This date is inclusive.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Type input for this Choreo. 
          # 
          # @param String - (optional, string) The analysis type you would like to get data for. Valid values are: general, unique, or average
          ###

          def set_Type(value)
            set_input("Type", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) Determines the buckets into which the property values that you segment on are placed. Valid values are: minute, hour, day (the default), or month.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., properties["Signed Up"]). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the SegmentationData Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class SegmentationDataResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class SegmentationData



      ##############################################################################
      #
      # Sum
      #
      # Sums an expression for events per unit time.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class Sum < Choreography

        ####
        #  Create a new instance of the Sum Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Mixpanel/DataExport/Segmentation/Sum")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return SumInputSet
        ####
        def new_input_set()
          return SumInputSet.new()
        end

        def make_result_set()
          return SumResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = SumResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the Sum
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class SumInputSet < Choreography::InputSet

          #### 
          # Set the value of the APIKey input for this Choreo. 
          # 
          # @param String - (required, string) The API Key provided my Mixpanel. You can find your Mixpanel API Key in the project settings dialog in the Mixpanel app.
          ###

          def set_APIKey(value)
            set_input("APIKey", value)
          end
          #### 
          # Set the value of the APISecret input for this Choreo. 
          # 
          # @param String - (required, string) The API Secret provided by Mixpanel. You can find your Mixpanel API Secret in the project settings dialog in the Mixpanel app.
          ###

          def set_APISecret(value)
            set_input("APISecret", value)
          end
          #### 
          # Set the value of the EventName input for this Choreo. 
          # 
          # @param String - (required, string) The event that you wish to segment on.
          ###

          def set_EventName(value)
            set_input("EventName", value)
          end
          #### 
          # Set the value of the Expire input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of minutes past NOW() before the request will expire. Defaults to 1.
          ###

          def set_Expire(value)
            set_input("Expire", value)
          end
          #### 
          # Set the value of the FromDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to begin querying for the event from. This date is inclusive.
          ###

          def set_FromDate(value)
            set_input("FromDate", value)
          end
          #### 
          # Set the value of the On input for this Choreo. 
          # 
          # @param String - (required, string) The expression to sum per unit time. Must be a numeric expression (e.g., number(properties["time"]). See Choreo description for examples.
          ###

          def set_On(value)
            set_input("On", value)
          end
          #### 
          # Set the value of the ToDate input for this Choreo. 
          # 
          # @param String - (required, date) The date in yyyy-mm-dd format from which to stop querying for the event from. This date is inclusive. The date range may not be more than 30 days.
          ###

          def set_ToDate(value)
            set_input("ToDate", value)
          end
          #### 
          # Set the value of the Unit input for this Choreo. 
          # 
          # @param String - (optional, string) Determines the buckets into which the property values that you segment on are placed. Valid values are: hour or day.
          ###

          def set_Unit(value)
            set_input("Unit", value)
          end
          #### 
          # Set the value of the Where input for this Choreo. 
          # 
          # @param String - (optional, string) An expression to filter events by  (e.g., number(properties["time"]) >= 2000). See Choreo description for examples.
          ###

          def set_Where(value)
            set_input("Where", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the Sum Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class SumResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from Mixpanel.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class Sum




    end # module Segmentation

  end # module DataExport

  module Events



    ##############################################################################
    #
    # Track
    #
    # Records an event in Mixpanel.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Track < Choreography

      ####
      #  Create a new instance of the Track Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Events/Track")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TrackInputSet
      ####
      def new_input_set()
        return TrackInputSet.new()
      end

      def make_result_set()
        return TrackResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TrackResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Track
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TrackInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (optional, string) Used to uniquely identify a user associated with your event. When provided, you can track a given user through funnels and distinguish unique users for retention analyses.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the EventName input for this Choreo. 
        # 
        # @param String - (required, string) A name for the event (e.g., Signed Up, Uploaded Photo, etc).
        ###

        def set_EventName(value)
          set_input("EventName", value)
        end
        #### 
        # Set the value of the EventProperties input for this Choreo. 
        # 
        # @param String - (optional, json) Additional properties associated with the event formatted as name/value pairs in a JSON object. These properties can be used for segmentation and funnels.
        ###

        def set_EventProperties(value)
          set_input("EventProperties", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the event (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time the event occurred. If not provided, Mixpanel will use the time the event arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Track Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TrackResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Track




  end # module Events

  module Profiles



    ##############################################################################
    #
    # Add
    #
    # Adds or subtracts a value from an existing numeric property value.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Add < Choreography

      ####
      #  Create a new instance of the Add Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Add")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AddInputSet
      ####
      def new_input_set()
        return AddInputSet.new()
      end

      def make_result_set()
        return AddResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AddResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Add
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AddInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (conditional, json) A JSON object containing names and values of custom profile properties. The current value will be added to any existing property value. If the property doesn't exist, the value will be added to 0.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Add Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AddResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Add



    ##############################################################################
    #
    # Append
    #
    # Appends a value to a list property on a profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Append < Choreography

      ####
      #  Create a new instance of the Append Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Append")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return AppendInputSet
      ####
      def new_input_set()
        return AppendInputSet.new()
      end

      def make_result_set()
        return AppendResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = AppendResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Append
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class AppendInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (conditional, json) A JSON object containing a name/value pair representing a list name and value. The current value will be appended to any existing lists. If the list doesn't exist, it will be created.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Append Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class AppendResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Append



    ##############################################################################
    #
    # Delete
    #
    # Permanently deletes the profile from Mixpanel, along with all of its properties.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Delete < Choreography

      ####
      #  Create a new instance of the Delete Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Delete")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteInputSet
      ####
      def new_input_set()
        return DeleteInputSet.new()
      end

      def make_result_set()
        return DeleteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Delete
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Delete Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Delete



    ##############################################################################
    #
    # Set
    #
    # Sets the properties of a profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Set < Choreography

      ####
      #  Create a new instance of the Set Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Set")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SetInputSet
      ####
      def new_input_set()
        return SetInputSet.new()
      end

      def make_result_set()
        return SetResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SetResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Set
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SetInputSet < Choreography::InputSet

        #### 
        # Set the value of the City input for this Choreo. 
        # 
        # @param String - (optional, string) The city associated with the user's location.
        ###

        def set_City(value)
          set_input("City", value)
        end
        #### 
        # Set the value of the Created input for this Choreo. 
        # 
        # @param String - (optional, date) The time when the user created their account. This should be expressed as YYYY-MM-DDThh:mm:ss.
        ###

        def set_Created(value)
          set_input("Created", value)
        end
        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the Email input for this Choreo. 
        # 
        # @param String - (optional, string) The user's email address. Mixpanel can use this property when sending email notifications to your users.
        ###

        def set_Email(value)
          set_input("Email", value)
        end
        #### 
        # Set the value of the FirstName input for this Choreo. 
        # 
        # @param String - (optional, string) The first name of the user represented the profile.
        ###

        def set_FirstName(value)
          set_input("FirstName", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the LastName input for this Choreo. 
        # 
        # @param String - (optional, string) The last name of the user representing the profile.
        ###

        def set_LastName(value)
          set_input("LastName", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (optional, string) The full name of the user. This can be used as an alternative to FirstName and LastName.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the Phone input for this Choreo. 
        # 
        # @param String - (optional, string) The user's phone number (e.g., 4805551212). Mixpanel can use this property when sending SMS messages to your users.
        ###

        def set_Phone(value)
          set_input("Phone", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing names and values of custom profile properties. Note that properties that exist already will be overwritten.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Region input for this Choreo. 
        # 
        # @param String - (optional, string) The region associated with a user's location.
        ###

        def set_Region(value)
          set_input("Region", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Timezone input for this Choreo. 
        # 
        # @param String - (optional, string) The timezone associated with a user's location.
        ###

        def set_Timezone(value)
          set_input("Timezone", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Set Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SetResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Set



    ##############################################################################
    #
    # SetOnce
    #
    # Sets the properties of a profile, but will not overwrite existing properties.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SetOnce < Choreography

      ####
      #  Create a new instance of the SetOnce Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/SetOnce")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SetOnceInputSet
      ####
      def new_input_set()
        return SetOnceInputSet.new()
      end

      def make_result_set()
        return SetOnceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SetOnceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SetOnce
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SetOnceInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (conditional, json) A JSON object containing names and values of custom profile properties. Note that properties existing already will not be overwritten.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SetOnce Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SetOnceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SetOnce



    ##############################################################################
    #
    # Transaction
    #
    # Appends transaction data to a profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Transaction < Choreography

      ####
      #  Create a new instance of the Transaction Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Transaction")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TransactionInputSet
      ####
      def new_input_set()
        return TransactionInputSet.new()
      end

      def make_result_set()
        return TransactionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TransactionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Transaction
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TransactionInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the TransactionAmount input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The amount of the transaction.
        ###

        def set_TransactionAmount(value)
          set_input("TransactionAmount", value)
        end
        #### 
        # Set the value of the TransactionProperties input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing any transaction properties you wish to set (e.g. SKU, Product Name, etc).
        ###

        def set_TransactionProperties(value)
          set_input("TransactionProperties", value)
        end
        #### 
        # Set the value of the TransactionTime input for this Choreo. 
        # 
        # @param String - (conditional, date) The time of the transaction (e.g., 2013-01-03T09:00:00). If this isn't provided, the current time in UTC is specified.
        ###

        def set_TransactionTime(value)
          set_input("TransactionTime", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Transaction Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TransactionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Transaction



    ##############################################################################
    #
    # Union
    #
    # Merges list values with an existing list on a profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Union < Choreography

      ####
      #  Create a new instance of the Union Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Union")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UnionInputSet
      ####
      def new_input_set()
        return UnionInputSet.new()
      end

      def make_result_set()
        return UnionResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UnionResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Union
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UnionInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (required, json) A JSON object containing a list name and an array of values. The list values in the request are merged with the existing list on the user profile, ignoring duplicate list values.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Union Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UnionResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Union



    ##############################################################################
    #
    # Unset
    #
    # Removes the specified properties and their values from a profile.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Unset < Choreography

      ####
      #  Create a new instance of the Unset Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Mixpanel/Profiles/Unset")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UnsetInputSet
      ####
      def new_input_set()
        return UnsetInputSet.new()
      end

      def make_result_set()
        return UnsetResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UnsetResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Unset
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UnsetInputSet < Choreography::InputSet

        #### 
        # Set the value of the DistinctID input for this Choreo. 
        # 
        # @param String - (required, string) Used to uniquely identify the profile you want to update.
        ###

        def set_DistinctID(value)
          set_input("DistinctID", value)
        end
        #### 
        # Set the value of the IP input for this Choreo. 
        # 
        # @param String - (optional, string) An IP address string associated with the profile (e.g., 127.0.0.1). When set to 0 (the default) Mixpanel will ignore IP information.
        ###

        def set_IP(value)
          set_input("IP", value)
        end
        #### 
        # Set the value of the IgnoreTime input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, Mixpanel will not automatically update the "Last Seen" property of the profile. Otherwise, Mixpanel will add a "Last Seen" property associated with any set, append, or add requests.
        ###

        def set_IgnoreTime(value)
          set_input("IgnoreTime", value)
        end
        #### 
        # Set the value of the ProfileProperties input for this Choreo. 
        # 
        # @param String - (conditional, json) A JSON array of property names to remove from a profile.
        ###

        def set_ProfileProperties(value)
          set_input("ProfileProperties", value)
        end
        #### 
        # Set the value of the Time input for this Choreo. 
        # 
        # @param String - (optional, date) A unix timestamp representing the time of the profile update. If not provided, Mixpanel will use the time the update arrives at the server.
        ###

        def set_Time(value)
          set_input("Time", value)
        end
        #### 
        # Set the value of the Token input for this Choreo. 
        # 
        # @param String - (required, string) The token provided by Mixpanel. You can find your Mixpanel token in the project settings dialog in the Mixpanel app.
        ###

        def set_Token(value)
          set_input("Token", value)
        end
        #### 
        # Set the value of the Verbose input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to 1, the response will contain more information describing the success or failure of the tracking call.
        ###

        def set_Verbose(value)
          set_input("Verbose", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Unset Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UnsetResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Mixpanel.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Unset




  end # module Profiles

end # module Mixpanel