require "temboo"

module Plotly



  ##############################################################################
  #
  # ConfigureGraph
  #
  # Creates, modifies, or styles a graph.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ConfigureGraph < Choreography

    ####
    #  Create a new instance of the ConfigureGraph Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/ConfigureGraph")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ConfigureGraphInputSet
    ####
    def new_input_set()
      return ConfigureGraphInputSet.new()
    end

    def make_result_set()
      return ConfigureGraphResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ConfigureGraphResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ConfigureGraph
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ConfigureGraphInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the FileOption input for this Choreo. 
      # 
      # @param String - (required, string) The file operation being performed. Valid values are: "new", "overwrite", "append", or "extend". See Choreo description for more details.
      ###

      def set_FileOption(value)
        set_input("FileOption", value)
      end
      #### 
      # Set the value of the GraphArguments input for this Choreo. 
      # 
      # @param String - (conditional, json) The data and/or styling arguments. Typically, this is in the form of a JSON array where x and y are represented as arrays of numbers or strings. See Choreo description for more details.
      ###

      def set_GraphArguments(value)
        set_input("GraphArguments", value)
      end
      #### 
      # Set the value of the Layout input for this Choreo. 
      # 
      # @param String - (optional, json) A key-value paired JSON object that describes the layout of the plot (e.g., {"title": "Sensor Data"}).
      ###

      def set_Layout(value)
        set_input("Layout", value)
      end
      #### 
      # Set the value of the Origin input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies the type of call and the type of data in the Arguments parameter. Valid values are: plot (the default), style, or layout.
      ###

      def set_Origin(value)
        set_input("Origin", value)
      end
      #### 
      # Set the value of the Style input for this Choreo. 
      # 
      # @param String - (optional, json) A JSON object describing the style of the graph (e.g., {"type": "bar"}). This can be applied to every single trace (default) or to the traces specified in the optional Traces input.
      ###

      def set_Style(value)
        set_input("Style", value)
      end
      #### 
      # Set the value of the Traces input for this Choreo. 
      # 
      # @param String - (optional, json) Specifies the indices that the Style input object should be applied to. This should be formatted as a JSON array.
      ###

      def set_Traces(value)
        set_input("Traces", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ConfigureGraph Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ConfigureGraphResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ConfigureGraph



  ##############################################################################
  #
  # ExtendBarGraph
  #
  # Extends the specified bar graph by plotting a single addition point.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ExtendBarGraph < Choreography

    ####
    #  Create a new instance of the ExtendBarGraph Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/ExtendBarGraph")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ExtendBarGraphInputSet
    ####
    def new_input_set()
      return ExtendBarGraphInputSet.new()
    end

    def make_result_set()
      return ExtendBarGraphResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ExtendBarGraphResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ExtendBarGraph
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ExtendBarGraphInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValue input for this Choreo. 
      # 
      # @param String - (required, any) The "x" coordinate value to be plotted on the graph.
      ###

      def set_XValue(value)
        set_input("XValue", value)
      end
      #### 
      # Set the value of the YValue input for this Choreo. 
      # 
      # @param String - (required, any) The "y" coordinate value to be plotted on the graph.
      ###

      def set_YValue(value)
        set_input("YValue", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ExtendBarGraph Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ExtendBarGraphResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ExtendBarGraph



  ##############################################################################
  #
  # ExtendLineGraph
  #
  # Extends the specified line graph by plotting a single addition point.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ExtendLineGraph < Choreography

    ####
    #  Create a new instance of the ExtendLineGraph Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/ExtendLineGraph")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ExtendLineGraphInputSet
    ####
    def new_input_set()
      return ExtendLineGraphInputSet.new()
    end

    def make_result_set()
      return ExtendLineGraphResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ExtendLineGraphResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ExtendLineGraph
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ExtendLineGraphInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValue input for this Choreo. 
      # 
      # @param String - (required, any) The "x" coordinate value to be plotted on the graph.
      ###

      def set_XValue(value)
        set_input("XValue", value)
      end
      #### 
      # Set the value of the YValue input for this Choreo. 
      # 
      # @param String - (required, any) The "y" coordinate value to be plotted on the graph.
      ###

      def set_YValue(value)
        set_input("YValue", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ExtendLineGraph Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ExtendLineGraphResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ExtendLineGraph



  ##############################################################################
  #
  # ExtendTimeSeries
  #
  # Extends the specified time series graph by plotting a single addition point.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class ExtendTimeSeries < Choreography

    ####
    #  Create a new instance of the ExtendTimeSeries Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/ExtendTimeSeries")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return ExtendTimeSeriesInputSet
    ####
    def new_input_set()
      return ExtendTimeSeriesInputSet.new()
    end

    def make_result_set()
      return ExtendTimeSeriesResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = ExtendTimeSeriesResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the ExtendTimeSeries
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class ExtendTimeSeriesInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the TimeZone input for this Choreo. 
      # 
      # @param String - (optional, string) If a value is not passed to the Timestamp input, the current is generated for you. When using this feature, you can indicate the desired time zone using this input. The default TimeZone is UTC.
      ###

      def set_TimeZone(value)
        set_input("TimeZone", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValue input for this Choreo. 
      # 
      # @param String - (conditional, date) The "x" coordinate timestamp to be plotted on the graph in the format YYYY-MM-DD HH:MM:SS. If not provided, this defaults to NOW().
      ###

      def set_XValue(value)
        set_input("XValue", value)
      end
      #### 
      # Set the value of the YValue input for this Choreo. 
      # 
      # @param String - (required, string) The "y" coordinate value associated with the specified timestamp.
      ###

      def set_YValue(value)
        set_input("YValue", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the ExtendTimeSeries Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class ExtendTimeSeriesResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class ExtendTimeSeries



  ##############################################################################
  #
  # PlotBarGraph
  #
  # Plots an array of points on a bar graph.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class PlotBarGraph < Choreography

    ####
    #  Create a new instance of the PlotBarGraph Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/PlotBarGraph")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return PlotBarGraphInputSet
    ####
    def new_input_set()
      return PlotBarGraphInputSet.new()
    end

    def make_result_set()
      return PlotBarGraphResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = PlotBarGraphResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the PlotBarGraph
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class PlotBarGraphInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the FileOption input for this Choreo. 
      # 
      # @param String - (optional, string) The file operation being performed. Valid values are: "new", "overwrite", "append", or "extend". See Choreo description for more details. This defaults to "overwrite".
      ###

      def set_FileOption(value)
        set_input("FileOption", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValues input for this Choreo. 
      # 
      # @param String - (required, json) A JSON array containing the "x" coordinate values to be plotted on the graph.
      ###

      def set_XValues(value)
        set_input("XValues", value)
      end
      #### 
      # Set the value of the YValues input for this Choreo. 
      # 
      # @param String - (required, json) A JSON array containing the "y" coordinate values to be plotted on the graph.
      ###

      def set_YValues(value)
        set_input("YValues", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the PlotBarGraph Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class PlotBarGraphResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class PlotBarGraph



  ##############################################################################
  #
  # PlotLineGraph
  #
  # Plots an array of points on a line graph.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class PlotLineGraph < Choreography

    ####
    #  Create a new instance of the PlotLineGraph Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/PlotLineGraph")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return PlotLineGraphInputSet
    ####
    def new_input_set()
      return PlotLineGraphInputSet.new()
    end

    def make_result_set()
      return PlotLineGraphResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = PlotLineGraphResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the PlotLineGraph
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class PlotLineGraphInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the FileOption input for this Choreo. 
      # 
      # @param String - (optional, string) The file operation being performed. Valid values are: "new", "overwrite", "append", or "extend". See Choreo description for more details. This defaults to "overwrite".
      ###

      def set_FileOption(value)
        set_input("FileOption", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValues input for this Choreo. 
      # 
      # @param String - (required, json) A JSON array containing the "x" coordinate values to be plotted on the graph.
      ###

      def set_XValues(value)
        set_input("XValues", value)
      end
      #### 
      # Set the value of the YValues input for this Choreo. 
      # 
      # @param String - (required, json) A JSON array containing the "y" coordinate values to be plotted on the graph.
      ###

      def set_YValues(value)
        set_input("YValues", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the PlotLineGraph Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class PlotLineGraphResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class PlotLineGraph



  ##############################################################################
  #
  # PlotTimeSeries
  #
  # Plots an array of time series data on a graph.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class PlotTimeSeries < Choreography

    ####
    #  Create a new instance of the PlotTimeSeries Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/Plotly/PlotTimeSeries")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return PlotTimeSeriesInputSet
    ####
    def new_input_set()
      return PlotTimeSeriesInputSet.new()
    end

    def make_result_set()
      return PlotTimeSeriesResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = PlotTimeSeriesResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the PlotTimeSeries
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class PlotTimeSeriesInputSet < Choreography::InputSet

      #### 
      # Set the value of the APIKey input for this Choreo. 
      # 
      # @param String - (required, string) The API Key provided by Plotly.
      ###

      def set_APIKey(value)
        set_input("APIKey", value)
      end
      #### 
      # Set the value of the FileName input for this Choreo. 
      # 
      # @param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
      ###

      def set_FileName(value)
        set_input("FileName", value)
      end
      #### 
      # Set the value of the FileOption input for this Choreo. 
      # 
      # @param String - (optional, string) The file operation being performed. Valid values are: "new", "overwrite", "append", or "extend". See Choreo description for more details. This defaults to "overwrite".
      ###

      def set_FileOption(value)
        set_input("FileOption", value)
      end
      #### 
      # Set the value of the Title input for this Choreo. 
      # 
      # @param String - (optional, string) The title of the graph.
      ###

      def set_Title(value)
        set_input("Title", value)
      end
      #### 
      # Set the value of the Username input for this Choreo. 
      # 
      # @param String - (required, string) A valid Plotly username.
      ###

      def set_Username(value)
        set_input("Username", value)
      end
      #### 
      # Set the value of the WorldReadable input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
      ###

      def set_WorldReadable(value)
        set_input("WorldReadable", value)
      end
      #### 
      # Set the value of the XValues input for this Choreo. 
      # 
      # @param String - (required, json) A JSON array of timestamps representing the "x" coordinates to be plotted on the graph. Timestamps should be formatted as YYYY-MM-DD HH:MM:SS.
      ###

      def set_XValues(value)
        set_input("XValues", value)
      end
      #### 
      # Set the value of the YValues input for this Choreo. 
      # 
      # @param String - (required, json) A  JSON array of values representing the "y" coordinates associated with the specified timestamps.
      ###

      def set_YValues(value)
        set_input("YValues", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the PlotTimeSeries Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class PlotTimeSeriesResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "URL" output from this Choreo execution
    	#
    	# @return String - (string) The Plotly URL for the graph.
    	####
    	def get_URL()
    	  return @outputs["URL"]
    	end
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - (json) The response from Plotly
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class PlotTimeSeries




end # module Plotly