require "temboo"

module WolframAlpha



  ##############################################################################
  #
  # GetSearchResult
  #
  # Allows your application to submit a query to Wolfram|Alpha and return only the plain text from the first result pod.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class GetSearchResult < Choreography

    ####
    #  Create a new instance of the GetSearchResult Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/WolframAlpha/GetSearchResult")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return GetSearchResultInputSet
    ####
    def new_input_set()
      return GetSearchResultInputSet.new()
    end

    def make_result_set()
      return GetSearchResultResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = GetSearchResultResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the GetSearchResult
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class GetSearchResultInputSet < Choreography::InputSet

      #### 
      # Set the value of the AppID input for this Choreo. 
      # 
      # @param String - (required, string) The App ID provided by Wolfram|Alpha.
      ###

      def set_AppID(value)
        set_input("AppID", value)
      end
      #### 
      # Set the value of the Input input for this Choreo. 
      # 
      # @param String - (required, string) Specifies the input string (e.g., "5 largest countries").
      ###

      def set_Input(value)
        set_input("Input", value)
      end
      #### 
      # Set the value of the Latitude input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) When query results depend on your location, use this parameter to specify a latitude point.
      ###

      def set_Latitude(value)
        set_input("Latitude", value)
      end
      #### 
      # Set the value of the Location input for this Choreo. 
      # 
      # @param String - (optional, string) When query results depend on your location, use this parameter to specify a location such as "Los Angeles, CA", or "Madrid".
      ###

      def set_Location(value)
        set_input("Location", value)
      end
      #### 
      # Set the value of the Longitude input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) When query results depend on your location, use this parameter to specify a longitude point.
      ###

      def set_Longitude(value)
        set_input("Longitude", value)
      end
      #### 
      # Set the value of the ResponseFormat input for this Choreo. 
      # 
      # @param String - (optional, string) The format for the response. Valid values are JSON and XML. This will be ignored when providng an XPath query because results are returned as a string or JSON depending on the Mode specified.
      ###

      def set_ResponseFormat(value)
        set_input("ResponseFormat", value)
      end
      #### 
      # Set the value of the Translation input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) Whether to allow Wolfram Alpha to try to translate simple queries into English. Defaults to true.
      ###

      def set_Translation(value)
        set_input("Translation", value)
      end
      #### 
      # Set the value of the Units input for this Choreo. 
      # 
      # @param String - (optional, string) Lets you specify the preferred measurement system, either "metric" or "nonmetric" (U.S. customary units).
      ###

      def set_Units(value)
        set_input("Units", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the GetSearchResult Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class GetSearchResultResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Result" output from this Choreo execution
    	#
    	# @return String - (string) The plain text result parsed from the Wolfram Alpha response.
    	####
    	def get_Result()
    	  return @outputs["Result"]
    	end
    end

  end # class GetSearchResult



  ##############################################################################
  #
  # Query
  #
  # Allows your application to submit free-form queries similar to the queries one might enter at the Wolfram|Alpha website.
  #
  # Copyright 2014, Temboo Inc.
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing,
  # software distributed under the License is distributed on an
  # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
  # either express or implied. See the License for the specific
  # language governing permissions and limitations under the License.
  #
  ##############################################################################

  class Query < Choreography

    ####
    #  Create a new instance of the Query Choreo. A TembooSession object, containing a valid
    #  set of Temboo credentials, must be supplied.
    ####
    def initialize(session)
      super(session, "/Library/WolframAlpha/Query")
    end

    #### 
    # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
    #
    # @return QueryInputSet
    ####
    def new_input_set()
      return QueryInputSet.new()
    end

    def make_result_set()
      return QueryResultSet.new()
    end

    ####
    # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
    # and return a ResultSet containing the execution results.
    # @param choreoInputs
    # @return
    # @throws TembooException
    ####
    def execute(input_set = nil)
      resp = super(input_set)
      results = QueryResultSet.new(resp)
      return results
    end

    ####
    # An InputSet with methods appropriate for specifying the inputs to the Query
    # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
    ####
    class QueryInputSet < Choreography::InputSet

      #### 
      # Set the value of the AppID input for this Choreo. 
      # 
      # @param String - (required, string) The App ID provided by Wolfram|Alpha.
      ###

      def set_AppID(value)
        set_input("AppID", value)
      end
      #### 
      # Set the value of the Assumption input for this Choreo. 
      # 
      # @param String - (optional, string) Up to 10 comma-seperated assumptions to narrow a query.  Wolfram|Alpha provides you with a list of assumptons in the response of a previous query.  Please consult the documentation for more details.
      ###

      def set_Assumption(value)
        set_input("Assumption", value)
      end
      #### 
      # Set the value of the Async input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) Set to true to specify that asynchronous mode should be used. This allows partial results to come back before all the pods are computed.
      ###

      def set_Async(value)
        set_input("Async", value)
      end
      #### 
      # Set the value of the ExcludePodID input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies the IDs of the pod(s) to exlude from the response. All pod IDs are returned by default.
      ###

      def set_ExcludePodID(value)
        set_input("ExcludePodID", value)
      end
      #### 
      # Set the value of the Format input for this Choreo. 
      # 
      # @param String - (optional, string) The desired result formats separated by commas. Valid values are image, plaintext, minput, moutput, cell, mathml, imagemap, sound, wav. Defaults to "plaintext,image".
      ###

      def set_Format(value)
        set_input("Format", value)
      end
      #### 
      # Set the value of the FormatTimeout input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) The number of seconds to allow Wolfram Alpha to spend in the "format" stage for the entire collection of pods. Default value is 8.0.
      ###

      def set_FormatTimeout(value)
        set_input("FormatTimeout", value)
      end
      #### 
      # Set the value of the IgnoreCase input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) Whether to force Wolfram Alpha to ignore case in queries. Defaults to false.
      ###

      def set_IgnoreCase(value)
        set_input("IgnoreCase", value)
      end
      #### 
      # Set the value of the IncludePodID input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies the IDs of the pod(s) to include in the response. All pod IDs are returned by default.
      ###

      def set_IncludePodID(value)
        set_input("IncludePodID", value)
      end
      #### 
      # Set the value of the Input input for this Choreo. 
      # 
      # @param String - (required, string) Specifies the input string (e.g., "5 largest countries").
      ###

      def set_Input(value)
        set_input("Input", value)
      end
      #### 
      # Set the value of the Latitude input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) When query results depend on your location, use this parameter to specify a latitude point.
      ###

      def set_Latitude(value)
        set_input("Latitude", value)
      end
      #### 
      # Set the value of the Location input for this Choreo. 
      # 
      # @param String - (optional, string) When query results depend on your location, use this parameter to specify a location such as "Los Angeles, CA", or "Madrid".
      ###

      def set_Location(value)
        set_input("Location", value)
      end
      #### 
      # Set the value of the Longitude input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) When query results depend on your location, use this parameter to specify a longitude point.
      ###

      def set_Longitude(value)
        set_input("Longitude", value)
      end
      #### 
      # Set the value of the Magnification input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) Controls the magnification of pod images. The default value is 1.0, indicating no magnification.
      ###

      def set_Magnification(value)
        set_input("Magnification", value)
      end
      #### 
      # Set the value of the MaxWidth input for this Choreo. 
      # 
      # @param Integer - (optional, integer) Used to change the default width of pod images. Width and MaxWidth apply to images of text and tables. This can be used to avoid undesirable line breaks if the value of Width is too small.
      ###

      def set_MaxWidth(value)
        set_input("MaxWidth", value)
      end
      #### 
      # Set the value of the ParseTimeout input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) The number of seconds to allow Wolfram Alpha to spend in the "parsing" stage of processing. Default value is 5.0.
      ###

      def set_ParseTimeout(value)
        set_input("ParseTimeout", value)
      end
      #### 
      # Set the value of the PlotWidth input for this Choreo. 
      # 
      # @param Integer - (optional, integer) Controls the width at which plots and graphics are rendered. The default value is 200 pixels.
      ###

      def set_PlotWidth(value)
        set_input("PlotWidth", value)
      end
      #### 
      # Set the value of the PodIndex input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies the index of the pod(s) to return. This is an alternative to specifying pods by title or ID. You can give a single number or a sequence like "2,3,5".
      ###

      def set_PodIndex(value)
        set_input("PodIndex", value)
      end
      #### 
      # Set the value of the PodState input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies a pod state change, which replaces a pod with a modified version, such as a switch from Imperial to metric units.
      ###

      def set_PodState(value)
        set_input("PodState", value)
      end
      #### 
      # Set the value of the PodTimeout input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) The number of seconds to allow Wolfram Alpha to spend in the "format" stage for any one pod. Default value is 4.0.
      ###

      def set_PodTimeout(value)
        set_input("PodTimeout", value)
      end
      #### 
      # Set the value of the PodTitle input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies the titles of the pod(s) to include in the response. All pod titles are returned by default. You can use * as a wildcard to match zero or more characters in pod titles.
      ###

      def set_PodTitle(value)
        set_input("PodTitle", value)
      end
      #### 
      # Set the value of the Reinterpret input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) Whether to allow Wolfram Alpha to reinterpret queries that would otherwise not be understood. Defaults to false.
      ###

      def set_Reinterpret(value)
        set_input("Reinterpret", value)
      end
      #### 
      # Set the value of the ResponseFormat input for this Choreo. 
      # 
      # @param String - (optional, string) The format for the response. Valid values are JSON and XML. This will be ignored when providng an XPath query because results are returned as a string or JSON depending on the Mode specified.
      ###

      def set_ResponseFormat(value)
        set_input("ResponseFormat", value)
      end
      #### 
      # Set the value of the ScanTimeout input for this Choreo. 
      # 
      # @param BigDecimal - (optional, decimal) The number of seconds to allow Wolfram Alpha to compute results in the "scan" stage of processing. Default value is 3.0.
      ###

      def set_ScanTimeout(value)
        set_input("ScanTimeout", value)
      end
      #### 
      # Set the value of the Scanner input for this Choreo. 
      # 
      # @param String - (optional, string) Specifies that only pods produced by the given scanner should be returned. (e.g. Numeric, Music).  Defaults to all pods.
      ###

      def set_Scanner(value)
        set_input("Scanner", value)
      end
      #### 
      # Set the value of the Translation input for this Choreo. 
      # 
      # @param Boolean - (optional, boolean) Whether to allow Wolfram Alpha to try to translate simple queries into English. Defaults to true.
      ###

      def set_Translation(value)
        set_input("Translation", value)
      end
      #### 
      # Set the value of the Units input for this Choreo. 
      # 
      # @param String - (optional, string) Lets you specify the preferred measurement system, either "metric" or "nonmetric" (U.S. customary units).
      ###

      def set_Units(value)
        set_input("Units", value)
      end
      #### 
      # Set the value of the Width input for this Choreo. 
      # 
      # @param Integer - (optional, integer) Used to change the default width of pod images. The default is 500 pixels. Width and MaxWidth apply to images of text and tables.
      ###

      def set_Width(value)
        set_input("Width", value)
      end
      #### 
      # Set the value of the XPath input for this Choreo. 
      # 
      # @param String - (optional, string) An XPath query to apply to the API results.
      ###

      def set_XPath(value)
        set_input("XPath", value)
      end
      #### 
      # Set the value of the XPathMode input for this Choreo. 
      # 
      # @param String - (optional, string) Valid values are "select" (the default) or "recursive". Recursive mode will iterate using the provided XPath. Select mode will return the first match at the position indicated by the provided XPath.
      ###

      def set_XPathMode(value)
        set_input("XPathMode", value)
      end
      #### 
      # Set the value of the XPathRegex input for this Choreo. 
      # 
      # @param String - (optional, string) A regular expression that can be applied to the result of the XPath query provided.
      ###

      def set_XPathRegex(value)
        set_input("XPathRegex", value)
      end

    end

    ####
    # A ResultSet with methods tailored to the values returned by the Query Choreo.
    # The ResultSet object is used to retrieve the results of a Choreo execution.
    ####
    class QueryResultSet < Choreography::ResultSet
    	####
    	# Retrieve the value for the "Response" output from this Choreo execution
    	#
    	# @return String - The response from Wolfram Alpha.
    	####
    	def get_Response()
    	  return @outputs["Response"]
    	end
    end

  end # class Query




end # module WolframAlpha