require "temboo"

module Yahoo




  module Finance



    ##############################################################################
    #
    # GetNews
    #
    # Retrieves the most recent Yahoo Finance Company or Industry news items as an RSS feed.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetNews < Choreography

      ####
      #  Create a new instance of the GetNews Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Finance/GetNews")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetNewsInputSet
      ####
      def new_input_set()
        return GetNewsInputSet.new()
      end

      def make_result_set()
        return GetNewsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetNewsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetNews
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetNewsInputSet < Choreography::InputSet

        #### 
        # Set the value of the Company input for this Choreo. 
        # 
        # @param String - (required, string) Ticker symbol for one or more companies to search, separated by commas (e.g. YHOO,DIS to include news about Yahoo! and Disney).
        ###

        def set_Company(value)
          set_input("Company", value)
        end
        #### 
        # Set the value of the NewsType input for this Choreo. 
        # 
        # @param String - (required, string) Enter the type of news items you want to see in the RSS feed: headline or industry.
        ###

        def set_NewsType(value)
          set_input("NewsType", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetNews Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetNewsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo Finance.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetNews



    ##############################################################################
    #
    # GetStockQuote
    #
    # Retrieves information for the specified stock symbol from Yahoo Finance.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetStockQuote < Choreography

      ####
      #  Create a new instance of the GetStockQuote Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Finance/GetStockQuote")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetStockQuoteInputSet
      ####
      def new_input_set()
        return GetStockQuoteInputSet.new()
      end

      def make_result_set()
        return GetStockQuoteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetStockQuoteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetStockQuote
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetStockQuoteInputSet < Choreography::InputSet

        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the StockSymbol input for this Choreo. 
        # 
        # @param String - (required, string) The stock ticker symbol to search for (e.g., AAPL, GOOG, etc).
        ###

        def set_StockSymbol(value)
          set_input("StockSymbol", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetStockQuote Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetStockQuoteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Ask" output from this Choreo execution
      	#
      	# @return String - (decimal) The asking price.
      	####
      	def get_Ask()
      	  return @outputs["Ask"]
      	end
      	####
      	# Retrieve the value for the "Bid" output from this Choreo execution
      	#
      	# @return String - (decimal) The bid price.
      	####
      	def get_Bid()
      	  return @outputs["Bid"]
      	end
      	####
      	# Retrieve the value for the "Change" output from this Choreo execution
      	#
      	# @return String - (string) The change in the stock price.
      	####
      	def get_Change()
      	  return @outputs["Change"]
      	end
      	####
      	# Retrieve the value for the "DaysHigh" output from this Choreo execution
      	#
      	# @return String - (decimal) The high price of the day.
      	####
      	def get_DaysHigh()
      	  return @outputs["DaysHigh"]
      	end
      	####
      	# Retrieve the value for the "DaysLow" output from this Choreo execution
      	#
      	# @return String - (decimal) The low price of the day.
      	####
      	def get_DaysLow()
      	  return @outputs["DaysLow"]
      	end
      	####
      	# Retrieve the value for the "LastTradePriceOnly" output from this Choreo execution
      	#
      	# @return String - (decimal) The last trade price.
      	####
      	def get_LastTradePriceOnly()
      	  return @outputs["LastTradePriceOnly"]
      	end
      	####
      	# Retrieve the value for the "Open" output from this Choreo execution
      	#
      	# @return String - (decimal) The price when the market last opened.
      	####
      	def get_Open()
      	  return @outputs["Open"]
      	end
      	####
      	# Retrieve the value for the "PreviousClose" output from this Choreo execution
      	#
      	# @return String - (decimal) The previous closing price.
      	####
      	def get_PreviousClose()
      	  return @outputs["PreviousClose"]
      	end
      	####
      	# Retrieve the value for the "Volume" output from this Choreo execution
      	#
      	# @return String - (integer) The volume traded.
      	####
      	def get_Volume()
      	  return @outputs["Volume"]
      	end
      	####
      	# Retrieve the value for the "YearHigh" output from this Choreo execution
      	#
      	# @return String - (decimal) The price for the year high.
      	####
      	def get_YearHigh()
      	  return @outputs["YearHigh"]
      	end
      	####
      	# Retrieve the value for the "YearLow" output from this Choreo execution
      	#
      	# @return String - (decimal) The price for the year low.
      	####
      	def get_YearLow()
      	  return @outputs["YearLow"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo Finance.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetStockQuote




  end # module Finance

  module PlaceFinder



    ##############################################################################
    #
    # FindByAddress
    #
    # Retrieves complete geocoding information for a location by specifying an address or partial address.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FindByAddress < Choreography

      ####
      #  Create a new instance of the FindByAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/PlaceFinder/FindByAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FindByAddressInputSet
      ####
      def new_input_set()
        return FindByAddressInputSet.new()
      end

      def make_result_set()
        return FindByAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FindByAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FindByAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FindByAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the Address input for this Choreo. 
        # 
        # @param String - (required, string) The address to be searched.
        ###

        def set_Address(value)
          set_input("Address", value)
        end
        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the GeocodeFlags input for this Choreo. 
        # 
        # @param String - (optional, string) Affects how geocoding is performed for the request. Valid value are: A, C, L, Q, or R. See documentation for more details on this parameter.
        ###

        def set_GeocodeFlags(value)
          set_input("GeocodeFlags", value)
        end
        #### 
        # Set the value of the ResponseFlags input for this Choreo. 
        # 
        # @param String - (optional, string) Determines which data elements are returned in the response. Valid values are: B, C, D, E, G, I, J, Q, R, T, U, W, X. See documentation for details on this parameter.
        ###

        def set_ResponseFlags(value)
          set_input("ResponseFlags", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FindByAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FindByAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Latitude" output from this Choreo execution
      	#
      	# @return String - (decimal) The latitude coordinate for the location.
      	####
      	def get_Latitude()
      	  return @outputs["Latitude"]
      	end
      	####
      	# Retrieve the value for the "Longitude" output from this Choreo execution
      	#
      	# @return String - (decimal) The longitude coordinate for the location.
      	####
      	def get_Longitude()
      	  return @outputs["Longitude"]
      	end
      	####
      	# Retrieve the value for the "WOEID" output from this Choreo execution
      	#
      	# @return String - (integer) The unique Where On Earth ID of the location.
      	####
      	def get_WOEID()
      	  return @outputs["WOEID"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo PlaceFinder.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class FindByAddress



    ##############################################################################
    #
    # FindByCoordinates
    #
    # Retrieves complete location information from a specified pair of latitude and longitude coordinates.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FindByCoordinates < Choreography

      ####
      #  Create a new instance of the FindByCoordinates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/PlaceFinder/FindByCoordinates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FindByCoordinatesInputSet
      ####
      def new_input_set()
        return FindByCoordinatesInputSet.new()
      end

      def make_result_set()
        return FindByCoordinatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FindByCoordinatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FindByCoordinates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FindByCoordinatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the GeocodeFlags input for this Choreo. 
        # 
        # @param String - (optional, string) Affects how geocoding is performed for the request. Valid value are: A, C, L, Q, or R. See documentation for more details on this parameter.
        ###

        def set_GeocodeFlags(value)
          set_input("GeocodeFlags", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate of the location you want to find (e.g., 38.898717).
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude coordinate of the location you want to find (e.g., -77.035974).
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end
        #### 
        # Set the value of the ResponseFlags input for this Choreo. 
        # 
        # @param String - (optional, string) Determines which data elements are returned in the response. Valid values are: B, C, D, E, G, I, J, Q, R, T, U, W, X. See documentation for details on this parameter.
        ###

        def set_ResponseFlags(value)
          set_input("ResponseFlags", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FindByCoordinates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FindByCoordinatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "WOEID" output from this Choreo execution
      	#
      	# @return String - (integer) The unique Where On Earth ID of the location.
      	####
      	def get_WOEID()
      	  return @outputs["WOEID"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo PlaceFinder.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class FindByCoordinates




  end # module PlaceFinder

  module Weather



    ##############################################################################
    #
    # GetTemperature
    #
    # Retrieves the current temperature from Yahoo Weather for the specified location.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTemperature < Choreography

      ####
      #  Create a new instance of the GetTemperature Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Weather/GetTemperature")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTemperatureInputSet
      ####
      def new_input_set()
        return GetTemperatureInputSet.new()
      end

      def make_result_set()
        return GetTemperatureResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTemperatureResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTemperature
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTemperatureInputSet < Choreography::InputSet

        #### 
        # Set the value of the Address input for this Choreo. 
        # 
        # @param String - (required, string) The address to be searched.
        ###

        def set_Address(value)
          set_input("Address", value)
        end
        #### 
        # Set the value of the Units input for this Choreo. 
        # 
        # @param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
        ###

        def set_Units(value)
          set_input("Units", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTemperature Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTemperatureResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Temperature" output from this Choreo execution
      	#
      	# @return String - (integer) The current temperature (defaults to Fahrenheit).
      	####
      	def get_Temperature()
      	  return @outputs["Temperature"]
      	end
      end

    end # class GetTemperature



    ##############################################################################
    #
    # GetWeather
    #
    # Retrieves the Yahoo Weather RSS Feed for any specified location by WOEID.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetWeather < Choreography

      ####
      #  Create a new instance of the GetWeather Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Weather/GetWeather")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetWeatherInputSet
      ####
      def new_input_set()
        return GetWeatherInputSet.new()
      end

      def make_result_set()
        return GetWeatherResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetWeatherResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetWeather
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetWeatherInputSet < Choreography::InputSet

        #### 
        # Set the value of the Day input for this Choreo. 
        # 
        # @param Integer - (optional, integer) An index in the range 1 to 5 that corresponds to the forecast day you want to retrieve. Today corresponds to 1, tomorrow corresponds to 2, and so on. Defaults to 1.
        ###

        def set_Day(value)
          set_input("Day", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Units input for this Choreo. 
        # 
        # @param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
        ###

        def set_Units(value)
          set_input("Units", value)
        end
        #### 
        # Set the value of the WOEID input for this Choreo. 
        # 
        # @param Integer - (required, integer) Where On Earth ID for the desired location. This unique integer can be found by first running the GetWeatherByCoordinates Choreo.
        ###

        def set_WOEID(value)
          set_input("WOEID", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetWeather Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetWeatherResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ConditionCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the current condition.
      	####
      	def get_ConditionCode()
      	  return @outputs["ConditionCode"]
      	end
      	####
      	# Retrieve the value for the "ConditionText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the current condition.
      	####
      	def get_ConditionText()
      	  return @outputs["ConditionText"]
      	end
      	####
      	# Retrieve the value for the "ForecastCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the forecast condition.
      	####
      	def get_ForecastCode()
      	  return @outputs["ForecastCode"]
      	end
      	####
      	# Retrieve the value for the "ForecastText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the specified day's forecast condition.
      	####
      	def get_ForecastText()
      	  return @outputs["ForecastText"]
      	end
      	####
      	# Retrieve the value for the "High" output from this Choreo execution
      	#
      	# @return String - (integer) The high temperature forecast for the specified day.
      	####
      	def get_High()
      	  return @outputs["High"]
      	end
      	####
      	# Retrieve the value for the "Humidity" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric humidity.
      	####
      	def get_Humidity()
      	  return @outputs["Humidity"]
      	end
      	####
      	# Retrieve the value for the "Low" output from this Choreo execution
      	#
      	# @return String - (integer) The low temperature forecast for the specified day.
      	####
      	def get_Low()
      	  return @outputs["Low"]
      	end
      	####
      	# Retrieve the value for the "Pressure" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric pressure.
      	####
      	def get_Pressure()
      	  return @outputs["Pressure"]
      	end
      	####
      	# Retrieve the value for the "Temperature" output from this Choreo execution
      	#
      	# @return String - (integer) The current temperature.
      	####
      	def get_Temperature()
      	  return @outputs["Temperature"]
      	end
      	####
      	# Retrieve the value for the "Visibility" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for visibility.
      	####
      	def get_Visibility()
      	  return @outputs["Visibility"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo Weather.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetWeather



    ##############################################################################
    #
    # GetWeatherByAddress
    #
    # Retrieves the Yahoo Weather RSS Feed for any specified location by address.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetWeatherByAddress < Choreography

      ####
      #  Create a new instance of the GetWeatherByAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Weather/GetWeatherByAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetWeatherByAddressInputSet
      ####
      def new_input_set()
        return GetWeatherByAddressInputSet.new()
      end

      def make_result_set()
        return GetWeatherByAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetWeatherByAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetWeatherByAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetWeatherByAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the Address input for this Choreo. 
        # 
        # @param String - (required, string) The address to be searched.
        ###

        def set_Address(value)
          set_input("Address", value)
        end
        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the Day input for this Choreo. 
        # 
        # @param Integer - (optional, integer) An index in the range 1 to 5 that corresponds to the forecast day you want to retrieve. Today corresponds to 1, tomorrow corresponds to 2, and so on. Defaults to 1.
        ###

        def set_Day(value)
          set_input("Day", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Units input for this Choreo. 
        # 
        # @param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
        ###

        def set_Units(value)
          set_input("Units", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetWeatherByAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetWeatherByAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ConditionCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the current condition.
      	####
      	def get_ConditionCode()
      	  return @outputs["ConditionCode"]
      	end
      	####
      	# Retrieve the value for the "ConditionText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the current condition.
      	####
      	def get_ConditionText()
      	  return @outputs["ConditionText"]
      	end
      	####
      	# Retrieve the value for the "ForecastCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the forecast condition.
      	####
      	def get_ForecastCode()
      	  return @outputs["ForecastCode"]
      	end
      	####
      	# Retrieve the value for the "ForecastText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the specified day's forecast condition.
      	####
      	def get_ForecastText()
      	  return @outputs["ForecastText"]
      	end
      	####
      	# Retrieve the value for the "High" output from this Choreo execution
      	#
      	# @return String - (integer) The high temperature forecast for the specified day.
      	####
      	def get_High()
      	  return @outputs["High"]
      	end
      	####
      	# Retrieve the value for the "Humidity" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric humidity.
      	####
      	def get_Humidity()
      	  return @outputs["Humidity"]
      	end
      	####
      	# Retrieve the value for the "Low" output from this Choreo execution
      	#
      	# @return String - (integer) The low temperature forecast for the specified day.
      	####
      	def get_Low()
      	  return @outputs["Low"]
      	end
      	####
      	# Retrieve the value for the "Pressure" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric pressure.
      	####
      	def get_Pressure()
      	  return @outputs["Pressure"]
      	end
      	####
      	# Retrieve the value for the "Temperature" output from this Choreo execution
      	#
      	# @return String - (integer) The current temperature.
      	####
      	def get_Temperature()
      	  return @outputs["Temperature"]
      	end
      	####
      	# Retrieve the value for the "Visibility" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for visibility.
      	####
      	def get_Visibility()
      	  return @outputs["Visibility"]
      	end
      	####
      	# Retrieve the value for the "WOEID" output from this Choreo execution
      	#
      	# @return String - (integer) The unique Where On Earth ID of the location.
      	####
      	def get_WOEID()
      	  return @outputs["WOEID"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo Weather.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetWeatherByAddress



    ##############################################################################
    #
    # GetWeatherByCoordinates
    #
    # Retrieves the Yahoo Weather RSS Feed for any specified location by geo-coordinates.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetWeatherByCoordinates < Choreography

      ####
      #  Create a new instance of the GetWeatherByCoordinates Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/Weather/GetWeatherByCoordinates")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetWeatherByCoordinatesInputSet
      ####
      def new_input_set()
        return GetWeatherByCoordinatesInputSet.new()
      end

      def make_result_set()
        return GetWeatherByCoordinatesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetWeatherByCoordinatesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetWeatherByCoordinates
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetWeatherByCoordinatesInputSet < Choreography::InputSet

        #### 
        # Set the value of the AppID input for this Choreo. 
        # 
        # @param String - (optional, string) Deprecated (retained for backward compatibility only).
        ###

        def set_AppID(value)
          set_input("AppID", value)
        end
        #### 
        # Set the value of the Day input for this Choreo. 
        # 
        # @param Integer - (optional, integer) An index in the range 1 to 5 that corresponds to the forecast day you want to retrieve. Today corresponds to 1, tomorrow corresponds to 2, and so on. Defaults to 1.
        ###

        def set_Day(value)
          set_input("Day", value)
        end
        #### 
        # Set the value of the Latitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The latitude coordinate of the location you want to search (e.g., 38.898717).
        ###

        def set_Latitude(value)
          set_input("Latitude", value)
        end
        #### 
        # Set the value of the Longitude input for this Choreo. 
        # 
        # @param BigDecimal - (required, decimal) The longitude coordinate of the location you want to search (e.g., -77.035974).
        ###

        def set_Longitude(value)
          set_input("Longitude", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the Units input for this Choreo. 
        # 
        # @param String - (optional, string) The unit of temperature in the response. Acceptable inputs: f for Fahrenheit or c for Celsius. Defaults to f. When c is specified, all units measurements returned are changed to metric.
        ###

        def set_Units(value)
          set_input("Units", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetWeatherByCoordinates Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetWeatherByCoordinatesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "ConditionCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the current condition.
      	####
      	def get_ConditionCode()
      	  return @outputs["ConditionCode"]
      	end
      	####
      	# Retrieve the value for the "ConditionText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the current condition.
      	####
      	def get_ConditionText()
      	  return @outputs["ConditionText"]
      	end
      	####
      	# Retrieve the value for the "ForecastCode" output from this Choreo execution
      	#
      	# @return String - (integer) A code representing the forecast condition.
      	####
      	def get_ForecastCode()
      	  return @outputs["ForecastCode"]
      	end
      	####
      	# Retrieve the value for the "ForecastText" output from this Choreo execution
      	#
      	# @return String - (string) The textual description for the specified day's forecast condition.
      	####
      	def get_ForecastText()
      	  return @outputs["ForecastText"]
      	end
      	####
      	# Retrieve the value for the "High" output from this Choreo execution
      	#
      	# @return String - (integer) The high temperature forecast for the specified day.
      	####
      	def get_High()
      	  return @outputs["High"]
      	end
      	####
      	# Retrieve the value for the "Humidity" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric humidity.
      	####
      	def get_Humidity()
      	  return @outputs["Humidity"]
      	end
      	####
      	# Retrieve the value for the "Low" output from this Choreo execution
      	#
      	# @return String - (integer) The low temperature forecast for the specified day.
      	####
      	def get_Low()
      	  return @outputs["Low"]
      	end
      	####
      	# Retrieve the value for the "Pressure" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for atmospheric pressure.
      	####
      	def get_Pressure()
      	  return @outputs["Pressure"]
      	end
      	####
      	# Retrieve the value for the "Temperature" output from this Choreo execution
      	#
      	# @return String - (integer) The current temperature.
      	####
      	def get_Temperature()
      	  return @outputs["Temperature"]
      	end
      	####
      	# Retrieve the value for the "Visibility" output from this Choreo execution
      	#
      	# @return String - (decimal) The current measurement for visibility.
      	####
      	def get_Visibility()
      	  return @outputs["Visibility"]
      	end
      	####
      	# Retrieve the value for the "WOEID" output from this Choreo execution
      	#
      	# @return String - (integer) The unique Where On Earth ID of the location.
      	####
      	def get_WOEID()
      	  return @outputs["WOEID"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo Weather.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetWeatherByCoordinates




  end # module Weather

  module YQL



    ##############################################################################
    #
    # RunQuery
    #
    # Executes a specified YQL (Yahoo Query Language) statement.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RunQuery < Choreography

      ####
      #  Create a new instance of the RunQuery Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/YQL/RunQuery")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RunQueryInputSet
      ####
      def new_input_set()
        return RunQueryInputSet.new()
      end

      def make_result_set()
        return RunQueryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RunQueryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RunQuery
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RunQueryInputSet < Choreography::InputSet

        #### 
        # Set the value of the Diagnostics input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true" (the default), additional debug information about the request is returned.
        ###

        def set_Diagnostics(value)
          set_input("Diagnostics", value)
        end
        #### 
        # Set the value of the Query input for this Choreo. 
        # 
        # @param String - (required, string) A YQL (Yahoo! Query Language) statement to execute.
        ###

        def set_Query(value)
          set_input("Query", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RunQuery Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RunQueryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RunQuery



    ##############################################################################
    #
    # ScrapeWebPage
    #
    # Scrapes HTML from a web page and converts it to JSON or XML so that it can be reused by an application.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class ScrapeWebPage < Choreography

      ####
      #  Create a new instance of the ScrapeWebPage Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Yahoo/YQL/ScrapeWebPage")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ScrapeWebPageInputSet
      ####
      def new_input_set()
        return ScrapeWebPageInputSet.new()
      end

      def make_result_set()
        return ScrapeWebPageResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ScrapeWebPageResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the ScrapeWebPage
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ScrapeWebPageInputSet < Choreography::InputSet

        #### 
        # Set the value of the Diagnostics input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true" (the default), additional debug information about the request is returned.
        ###

        def set_Diagnostics(value)
          set_input("Diagnostics", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The URL of the web page to scrape.
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the XPATH input for this Choreo. 
        # 
        # @param String - (optional, string) An XPATH statement that can be used to extract specific information from the HTML.
        ###

        def set_XPATH(value)
          set_input("XPATH", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the ScrapeWebPage Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ScrapeWebPageResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from Yahoo.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class ScrapeWebPage




  end # module YQL

end # module Yahoo