class TembooInputDisallowedError < StandardError
    # Set up the input disallowed error.
    # * *params* :
    #   - +input_name+ -> Name of the input submitted that is not allowed.
    def initialize(input_name)
        @input_name = input_name
    end

    def get_input_name()
        return @input_name
    end
end

class TembooProxy
    # Set up a Temboo proxy to give the Javascript SDK access to your choreos.
    # * *params* :
    #   - +name+ -> Optional string naming a choreo to be set up immmediately.
    #   - +choreo+ -> Optional instantiated choreo to be set up immediately.
    #   - +inputs+ -> Optional input set for above choreo.
    #   - +allowed_user_inputs+ -> 0 or more strings naming allowed user inputs for above choreo.
    def initialize(name = nil, choreo = nil, inputs = nil, *allowed_user_inputs)
        # Where our whitelisted choreos will live.
        @choreos = Hash.new()

        # If we've got the salient info, go ahead and set one up.
        if name && choreo
            add_choreo(name, choreo, inputs, allowed_user_inputs)
        end
    end

    # Add a choreo to our Temboo proxy.
    # * *params* :
    #   - +name+ -> String of name under which this choreo will be stored in the proxy.
    #   - +choreo+ -> Instantiated choreo.
    #   - +inputs+ -> Optional input set for choreo.
    #   - +allowed_user_inputs+ -> 0 or more strings naming allowed user inputs for choreo.
    def add_choreo(name, choreo, inputs = nil, *allowed_user_inputs)
        unless choreo.class.name == 'TembooProxiedChoreo'
            choreo = TembooProxiedChoreo.new(choreo)
        end

        if inputs
            choreo.set_default_inputs(inputs)
        end

        if allowed_user_inputs.size > 0
            choreo.allow_user_inputs(allowed_user_inputs)
        end

        @choreos[name] = choreo
    end

    # Associate an input set with a specified choreo.
    # * *params* :
    #   - +name+ -> String of name under which target choreo is stored in proxy.
    #   - +inputs+ -> Instantiated input set to be added to choreo.
    def set_default_inputs(name, inputs)
        @choreos[name].set_default_inputs(inputs)
    end

    # Specify inputs that may be set by Javascript at execution time.
    # * *params* :
    #   - +name+ -> String of name under which choreo is stored in proxy.
    #   - +inputs+ -> Any number of strings naming inputs which may be set.
    def allow_user_inputs(name, *inputs)
        @choreos[name].allow_user_inputs(inputs)
    end


    # Execute a choreography.
    # * *params* :
    #   - +request+ -> Hash of properties loaded from Javascript request.
    #   - +json_encode+ -> Boolean indicating if the results should be JSON-encoded upon return.
    # * *returns* :
    #   - +outputs+ -> JSON-encoded string of outputs if json_encode is true, or output object if false.
    def execute(request, json_encode = true)
        begin
            if request.has_key?('inputs')
                inputs = request['inputs']
            else
                inputs = Hash.new()
            end
            
            if request.has_key?('outputFilters')
                output_filters = request['outputFilters']
            else
                output_filters = Hash.new()
            end
            
            if @choreos.has_key?(request['name'])
                choreo_results = @choreos[request['name']].execute(inputs, 
                                                                   output_filters, 
                                                                   request['version'])
            else
                raise TembooObjectNotAccessibleError.new('Proxied choreo not found.')
            end

            response = {'success' => true,
                        'outputs' => choreo_results.get_outputs()}

        rescue TembooInputDisallowedError => e
            response = {'error'     => true,
                        'type'      => 'DisallowedInput',
                        'message'   => e.message(),
                        'inputName' => e.get_input_name()}
        rescue TembooObjectNotAccessibleError => e
            response = {'error'     => true,
                        'type'      => 'NotFound',
                        'message'   => e.message()}
        rescue TembooHTTPError => e
            response = {'error'     => true,
                        'type'      => 'Execution',
                        'message'   => 'An error occurred during choreo execution. Check your Temboo logs for details.'}
        rescue TembooCredentialError => e
            response = {'error'     => true,
                        'type'      => 'Authentication',
                        'message'   => e.message()}
        rescue TembooError => e
            response = {'error'     => true,
                        'type'      => 'Temboo',
                        'message'   => e.message()}
        rescue Exception => e
            response = {'error'     => true,
                        'type'      => 'Server',
                        'info'      => e}
        end

        if json_encode
            return response.to_json()
        else
            return response
        end

    end
end

class TembooProxiedChoreo
    def initialize(choreo, inputs = nil, *allowed_user_inputs)
        @choreo = choreo
        set_default_inputs(inputs)
        @allowed_user_inputs = allowed_user_inputs
    end

    def set_default_inputs(inputs)
        if inputs.class.superclass == Choreography::InputSet
            @inputs = inputs            
        else
            @inputs = @choreo.new_input_set()
        end
    end

    def allow_user_inputs(inputs)
        inputs.each do |input|
            unless @allowed_user_inputs.include?(input)
                @allowed_user_inputs.push(input)
            end
        end
    end

    def execute(user_inputs, output_filters, version)
        @choreo.set_source(version)
        full_inputs = @inputs.clone()
        
        user_inputs.each do |key, val|
            if @allowed_user_inputs.include?(key)
                full_inputs.set_input(key, val)
            else
                raise TembooInputDisallowedError.new(key.to_s), "The user may not set this input."
            end
        end

        if !output_filters.empty?()
            output_filters.each do |name, props|
                full_inputs.add_output_filter(name, props['path'], props['variable'])
            end
        end
        outputs = @choreo.execute(full_inputs)
        return outputs
    end
end
