require "temboo"

module Utilities




  module Authentication




    module OAuth1



      ##############################################################################
      #
      # FinalizeOAuth
      #
      # Completes the OAuth process by retrieving an access token and access token secret for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class FinalizeOAuth < Choreography

        ####
        #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Utilities/Authentication/OAuth1/FinalizeOAuth")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return FinalizeOAuthInputSet
        ####
        def new_input_set()
          return FinalizeOAuthInputSet.new()
        end

        def make_result_set()
          return FinalizeOAuthResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = FinalizeOAuthResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class FinalizeOAuthInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessTokenURL input for this Choreo. 
          # 
          # @param String - (required, string) The URL for the authorization server that issues access tokens (e.g. https://api.dropbox.com/1/oauth/access_token).
          ###

          def set_AccessTokenURL(value)
            set_input("AccessTokenURL", value)
          end
          #### 
          # Set the value of the CallbackID input for this Choreo. 
          # 
          # @param String - (required, string) The callback ID returned by the InitializeOAuth Choreo. Used to retrieve the callback data after the user authorizes.
          ###

          def set_CallbackID(value)
            set_input("CallbackID", value)
          end
          #### 
          # Set the value of the ConsumerKey input for this Choreo. 
          # 
          # @param String - (required, string) The Consumer Key provided by the service.
          ###

          def set_ConsumerKey(value)
            set_input("ConsumerKey", value)
          end
          #### 
          # Set the value of the ConsumerSecret input for this Choreo. 
          # 
          # @param String - (required, string) The Consumer Secret provided by the service.
          ###

          def set_ConsumerSecret(value)
            set_input("ConsumerSecret", value)
          end
          #### 
          # Set the value of the OAuthTokenSecret input for this Choreo. 
          # 
          # @param String - (required, string) The oauth_token_secret retrieved during the OAuth process. This is returned by the InitializeOAuth Choreo.
          ###

          def set_OAuthTokenSecret(value)
            set_input("OAuthTokenSecret", value)
          end
          #### 
          # Set the value of the SuppressErrors input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
          ###

          def set_SuppressErrors(value)
            set_input("SuppressErrors", value)
          end
          #### 
          # Set the value of the Timeout input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
          ###

          def set_Timeout(value)
            set_input("Timeout", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class FinalizeOAuthResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
        	#
        	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
        	####
        	def get_ErrorMessage()
        	  return @outputs["ErrorMessage"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - (string) The response from the Authorization Server.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class FinalizeOAuth



      ##############################################################################
      #
      # InitializeOAuth
      #
      # Generates an authorization URL that an application can use to complete the first step in the OAuth 1.0 process.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class InitializeOAuth < Choreography

        ####
        #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Utilities/Authentication/OAuth1/InitializeOAuth")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return InitializeOAuthInputSet
        ####
        def new_input_set()
          return InitializeOAuthInputSet.new()
        end

        def make_result_set()
          return InitializeOAuthResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = InitializeOAuthResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class InitializeOAuthInputSet < Choreography::InputSet

          #### 
          # Set the value of the AuthorizationEndpoint input for this Choreo. 
          # 
          # @param String - (required, string) The endpoint that the user should be redirected to in order to authenticate and grant access (e.g. https://www.dropbox.com/1/oauth/authorize).
          ###

          def set_AuthorizationEndpoint(value)
            set_input("AuthorizationEndpoint", value)
          end
          #### 
          # Set the value of the ConsumerKey input for this Choreo. 
          # 
          # @param String - (required, string) The Consumer Key provided by the service.
          ###

          def set_ConsumerKey(value)
            set_input("ConsumerKey", value)
          end
          #### 
          # Set the value of the ConsumerSecret input for this Choreo. 
          # 
          # @param String - (required, string) The Consumer Secret provided by the service.
          ###

          def set_ConsumerSecret(value)
            set_input("ConsumerSecret", value)
          end
          #### 
          # Set the value of the ForwardingURL input for this Choreo. 
          # 
          # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
          ###

          def set_ForwardingURL(value)
            set_input("ForwardingURL", value)
          end
          #### 
          # Set the value of the RequestTokenEndpoint input for this Choreo. 
          # 
          # @param String - (required, string) The Authorization Server URL where the initial token request occurs (e.g. https://api.dropbox.com/1/oauth/request_token).
          ###

          def set_RequestTokenEndpoint(value)
            set_input("RequestTokenEndpoint", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class InitializeOAuthResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
        	#
        	# @return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
        	####
        	def get_AuthorizationURL()
        	  return @outputs["AuthorizationURL"]
        	end
        	####
        	# Retrieve the value for the "CallbackID" output from this Choreo execution
        	#
        	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
        	####
        	def get_CallbackID()
        	  return @outputs["CallbackID"]
        	end
        	####
        	# Retrieve the value for the "OAuthTokenSecret" output from this Choreo execution
        	#
        	# @return String - (string) The temporary OAuth Token Secret that can be exchanged for permanent tokens using the FinalizeOAuth Choreo.
        	####
        	def get_OAuthTokenSecret()
        	  return @outputs["OAuthTokenSecret"]
        	end
        end

      end # class InitializeOAuth




    end # module OAuth1

    module OAuth2



      ##############################################################################
      #
      # FinalizeOAuth
      #
      # Completes the OAuth process by retrieving an access token for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class FinalizeOAuth < Choreography

        ####
        #  Create a new instance of the FinalizeOAuth Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Utilities/Authentication/OAuth2/FinalizeOAuth")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return FinalizeOAuthInputSet
        ####
        def new_input_set()
          return FinalizeOAuthInputSet.new()
        end

        def make_result_set()
          return FinalizeOAuthResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = FinalizeOAuthResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the FinalizeOAuth
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class FinalizeOAuthInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessTokenEndpoint input for this Choreo. 
          # 
          # @param String - (required, string) The URL for the authorization server that issues access tokens (e.g. https://accounts.google.com/o/oauth2/token).
          ###

          def set_AccessTokenEndpoint(value)
            set_input("AccessTokenEndpoint", value)
          end
          #### 
          # Set the value of the CallbackID input for this Choreo. 
          # 
          # @param String - (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the authorization code after the user authorizes.
          ###

          def set_CallbackID(value)
            set_input("CallbackID", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (required, string) The Client ID provided by the service.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (required, string) The Client Secret provided by the service.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the SuppressErrors input for this Choreo. 
          # 
          # @param Boolean - (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
          ###

          def set_SuppressErrors(value)
            set_input("SuppressErrors", value)
          end
          #### 
          # Set the value of the Timeout input for this Choreo. 
          # 
          # @param Integer - (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
          ###

          def set_Timeout(value)
            set_input("Timeout", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the FinalizeOAuth Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class FinalizeOAuthResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "ErrorMessage" output from this Choreo execution
        	#
        	# @return String - (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
        	####
        	def get_ErrorMessage()
        	  return @outputs["ErrorMessage"]
        	end
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from the server.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class FinalizeOAuth



      ##############################################################################
      #
      # InitializeOAuth
      #
      # Generates an authorization URL that an application can use to complete the first step in the OAuth 2.0 process.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class InitializeOAuth < Choreography

        ####
        #  Create a new instance of the InitializeOAuth Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Utilities/Authentication/OAuth2/InitializeOAuth")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return InitializeOAuthInputSet
        ####
        def new_input_set()
          return InitializeOAuthInputSet.new()
        end

        def make_result_set()
          return InitializeOAuthResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = InitializeOAuthResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the InitializeOAuth
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class InitializeOAuthInputSet < Choreography::InputSet

          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (required, string) The Client ID provided by the service.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the CustomCallbackID input for this Choreo. 
          # 
          # @param String - (optional, string) A unique identifier that you can pass to eliminate the need to wait for a Temboo-generated CallbackID. Callback identifiers may only contain numbers, letters, periods, and hyphens.
          ###

          def set_CustomCallbackID(value)
            set_input("CustomCallbackID", value)
          end
          #### 
          # Set the value of the ForwardingURL input for this Choreo. 
          # 
          # @param String - (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
          ###

          def set_ForwardingURL(value)
            set_input("ForwardingURL", value)
          end
          #### 
          # Set the value of the RequestTokenEndpoint input for this Choreo. 
          # 
          # @param String - (required, string) The Authorization Server URL where the initial token request occurs (e.g. https://accounts.google.com/o/oauth2/auth).
          ###

          def set_RequestTokenEndpoint(value)
            set_input("RequestTokenEndpoint", value)
          end
          #### 
          # Set the value of the Scope input for this Choreo. 
          # 
          # @param String - (conditional, string) The OAuth scope that should be associated with the access token being requested. This is not always required. Typically, you can specify multiple scopes separated by spaces, commas, or pipes.
          ###

          def set_Scope(value)
            set_input("Scope", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the InitializeOAuth Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class InitializeOAuthResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "AuthorizationURL" output from this Choreo execution
        	#
        	# @return String - (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
        	####
        	def get_AuthorizationURL()
        	  return @outputs["AuthorizationURL"]
        	end
        	####
        	# Retrieve the value for the "CallbackID" output from this Choreo execution
        	#
        	# @return String - (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
        	####
        	def get_CallbackID()
        	  return @outputs["CallbackID"]
        	end
        end

      end # class InitializeOAuth



      ##############################################################################
      #
      # RefreshToken
      #
      # Refreshes an expired access token.
      #
      # Copyright 2014, Temboo Inc.
      #
      # Licensed under the Apache License, Version 2.0 (the "License");
      # you may not use this file except in compliance with the License.
      # You may obtain a copy of the License at
      #
      # http://www.apache.org/licenses/LICENSE-2.0
      #
      # Unless required by applicable law or agreed to in writing,
      # software distributed under the License is distributed on an
      # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
      # either express or implied. See the License for the specific
      # language governing permissions and limitations under the License.
      #
      ##############################################################################

      class RefreshToken < Choreography

        ####
        #  Create a new instance of the RefreshToken Choreo. A TembooSession object, containing a valid
        #  set of Temboo credentials, must be supplied.
        ####
        def initialize(session)
          super(session, "/Library/Utilities/Authentication/OAuth2/RefreshToken")
        end

        #### 
        # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
        #
        # @return RefreshTokenInputSet
        ####
        def new_input_set()
          return RefreshTokenInputSet.new()
        end

        def make_result_set()
          return RefreshTokenResultSet.new()
        end

        ####
        # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
        # and return a ResultSet containing the execution results.
        # @param choreoInputs
        # @return
        # @throws TembooException
        ####
        def execute(input_set = nil)
          resp = super(input_set)
          results = RefreshTokenResultSet.new(resp)
          return results
        end

        ####
        # An InputSet with methods appropriate for specifying the inputs to the RefreshToken
        # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
        ####
        class RefreshTokenInputSet < Choreography::InputSet

          #### 
          # Set the value of the AccessTokenEndpoint input for this Choreo. 
          # 
          # @param String - (required, string) The URL for the authorization server that issues access tokens (e.g. https://accounts.google.com/o/oauth2/token).
          ###

          def set_AccessTokenEndpoint(value)
            set_input("AccessTokenEndpoint", value)
          end
          #### 
          # Set the value of the ClientID input for this Choreo. 
          # 
          # @param String - (required, string) The Client ID provided by the service.
          ###

          def set_ClientID(value)
            set_input("ClientID", value)
          end
          #### 
          # Set the value of the ClientSecret input for this Choreo. 
          # 
          # @param String - (required, string) The Client Secret provided by the service.
          ###

          def set_ClientSecret(value)
            set_input("ClientSecret", value)
          end
          #### 
          # Set the value of the RefreshToken input for this Choreo. 
          # 
          # @param String - (required, string) The refresh token retrieved in the OAuth process to be used when your access token expires.
          ###

          def set_RefreshToken(value)
            set_input("RefreshToken", value)
          end

        end

        ####
        # A ResultSet with methods tailored to the values returned by the RefreshToken Choreo.
        # The ResultSet object is used to retrieve the results of a Choreo execution.
        ####
        class RefreshTokenResultSet < Choreography::ResultSet
        	####
        	# Retrieve the value for the "Response" output from this Choreo execution
        	#
        	# @return String - The response from the server.
        	####
        	def get_Response()
        	  return @outputs["Response"]
        	end
        end

      end # class RefreshToken




    end # module OAuth2

  end # module Authentication

  module Callback



    ##############################################################################
    #
    # GetCallbackData
    #
    # Retrieves data captured from a request to your callback URL.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetCallbackData < Choreography

      ####
      #  Create a new instance of the GetCallbackData Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Callback/GetCallbackData")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetCallbackDataInputSet
      ####
      def new_input_set()
        return GetCallbackDataInputSet.new()
      end

      def make_result_set()
        return GetCallbackDataResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetCallbackDataResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetCallbackData
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetCallbackDataInputSet < Choreography::InputSet

        #### 
        # Set the value of the CallbackID input for this Choreo. 
        # 
        # @param String - (required, string) The ID that can used to retrieve request data that the callback URL has captured.
        ###

        def set_CallbackID(value)
          set_input("CallbackID", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) Allows you to filter callback data by a query parameter key-value pair. FilterValue is required when using this input.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) Allows you to filter callback data by a query parameter key-value pair. FilterName is required when using this input.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetCallbackData Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetCallbackDataResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "CallbackData" output from this Choreo execution
      	#
      	# @return String - Contains the request data received at your CalllbackURL.
      	####
      	def get_CallbackData()
      	  return @outputs["CallbackData"]
      	end
      end

    end # class GetCallbackData



    ##############################################################################
    #
    # RegisterCallback
    #
    # Allows you to generate a unique URL that can "listen" for incoming data from web request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RegisterCallback < Choreography

      ####
      #  Create a new instance of the RegisterCallback Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Callback/RegisterCallback")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RegisterCallbackInputSet
      ####
      def new_input_set()
        return RegisterCallbackInputSet.new()
      end

      def make_result_set()
        return RegisterCallbackResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RegisterCallbackResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RegisterCallback
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RegisterCallbackInputSet < Choreography::InputSet

        #### 
        # Set the value of the CustomCallbackD input for this Choreo. 
        # 
        # @param String - (optional, string) This value is used to register a unique URL associated with your account. If omitted, a random identifier is generated. Using a custom value here is useful when you need the URL to be static.
        ###

        def set_CustomCallbackD(value)
          set_input("CustomCallbackD", value)
        end
        #### 
        # Set the value of the FilterName input for this Choreo. 
        # 
        # @param String - (optional, string) When using a Custom Callback ID, it can be useful to filter requests using a query parameter. This value is used as a query parameter name, and can be used to lookup request data.
        ###

        def set_FilterName(value)
          set_input("FilterName", value)
        end
        #### 
        # Set the value of the FilterValue input for this Choreo. 
        # 
        # @param String - (optional, string) When using a Custom Callback ID, it can be useful to filter requests using a query parameter. This value is used as a query parameter value, and can be used to lookup request data.
        ###

        def set_FilterValue(value)
          set_input("FilterValue", value)
        end
        #### 
        # Set the value of the ForwardingURL input for this Choreo. 
        # 
        # @param String - (optional, string) The URL that Temboo will redirect a users to after they visit your URL. This should include the "https://" or "http://" prefix and be a fully qualified URL.
        ###

        def set_ForwardingURL(value)
          set_input("ForwardingURL", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RegisterCallback Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RegisterCallbackResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "CallbackID" output from this Choreo execution
      	#
      	# @return String - (string) The ID that can used to retrieve request data that the Callback URL captures.
      	####
      	def get_CallbackID()
      	  return @outputs["CallbackID"]
      	end
      	####
      	# Retrieve the value for the "CallbackURL" output from this Choreo execution
      	#
      	# @return String - (string) The URL that is listening for an incoming request. Note that this URL will expire in 10 minutes.
      	####
      	def get_CallbackURL()
      	  return @outputs["CallbackURL"]
      	end
      end

    end # class RegisterCallback




  end # module Callback

  module DataConversions



    ##############################################################################
    #
    # CSVToJSON
    #
    # Converts a CSV formatted file to JSON.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CSVToJSON < Choreography

      ####
      #  Create a new instance of the CSVToJSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/CSVToJSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CSVToJSONInputSet
      ####
      def new_input_set()
        return CSVToJSONInputSet.new()
      end

      def make_result_set()
        return CSVToJSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CSVToJSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CSVToJSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CSVToJSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the CSV input for this Choreo. 
        # 
        # @param String - (required, multiline) The CSV file to convert to JSON. Your CSV data must contain column names.
        ###

        def set_CSV(value)
          set_input("CSV", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CSVToJSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CSVToJSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "JSON" output from this Choreo execution
      	#
      	# @return String - (json) The JSON formatted data.
      	####
      	def get_JSON()
      	  return @outputs["JSON"]
      	end
      end

    end # class CSVToJSON



    ##############################################################################
    #
    # CSVToXLS
    #
    # Converts a CSV formatted file to Base64 encoded Excel data.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CSVToXLS < Choreography

      ####
      #  Create a new instance of the CSVToXLS Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/CSVToXLS")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CSVToXLSInputSet
      ####
      def new_input_set()
        return CSVToXLSInputSet.new()
      end

      def make_result_set()
        return CSVToXLSResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CSVToXLSResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CSVToXLS
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CSVToXLSInputSet < Choreography::InputSet

        #### 
        # Set the value of the CSV input for this Choreo. 
        # 
        # @param String - (conditional, multiline) The CSV data you want to convert to XLS format. Required unless using the VaultFile input alias (an advanced option used when running Choreos in the Temboo Designer).
        ###

        def set_CSV(value)
          set_input("CSV", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) A path to a CSV file you've stored in the Vault. This can be used as an alternative to the CSVFile input variable.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CSVToXLS Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CSVToXLSResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XLS" output from this Choreo execution
      	#
      	# @return String - (string) The Base64 encoded Excel data.
      	####
      	def get_XLS()
      	  return @outputs["XLS"]
      	end
      end

    end # class CSVToXLS



    ##############################################################################
    #
    # CSVToXML
    #
    # Converts a CSV formatted file to XML.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CSVToXML < Choreography

      ####
      #  Create a new instance of the CSVToXML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/CSVToXML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CSVToXMLInputSet
      ####
      def new_input_set()
        return CSVToXMLInputSet.new()
      end

      def make_result_set()
        return CSVToXMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CSVToXMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CSVToXML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CSVToXMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the CSV input for this Choreo. 
        # 
        # @param String - (required, multiline) The CSV file to convert to XML. Your CSV data must contain column names.
        ###

        def set_CSV(value)
          set_input("CSV", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CSVToXML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CSVToXMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XML" output from this Choreo execution
      	#
      	# @return String - (xml) The XML formatted data.
      	####
      	def get_XML()
      	  return @outputs["XML"]
      	end
      end

    end # class CSVToXML



    ##############################################################################
    #
    # JSONToXML
    #
    # Converts data from JSON format to XML format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class JSONToXML < Choreography

      ####
      #  Create a new instance of the JSONToXML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/JSONToXML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return JSONToXMLInputSet
      ####
      def new_input_set()
        return JSONToXMLInputSet.new()
      end

      def make_result_set()
        return JSONToXMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = JSONToXMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the JSONToXML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class JSONToXMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the JSON input for this Choreo. 
        # 
        # @param String - (required, json) The JSON data that you want to convert to XML.
        ###

        def set_JSON(value)
          set_input("JSON", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the JSONToXML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class JSONToXMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XML" output from this Choreo execution
      	#
      	# @return String - (xml) The converted data in XML format.
      	####
      	def get_XML()
      	  return @outputs["XML"]
      	end
      end

    end # class JSONToXML



    ##############################################################################
    #
    # RSSToJSON
    #
    # Retrieves a specified RSS Feed, and converts it to JSON format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RSSToJSON < Choreography

      ####
      #  Create a new instance of the RSSToJSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/RSSToJSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RSSToJSONInputSet
      ####
      def new_input_set()
        return RSSToJSONInputSet.new()
      end

      def make_result_set()
        return RSSToJSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RSSToJSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RSSToJSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RSSToJSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the RSSFeed input for this Choreo. 
        # 
        # @param String - (required, string) The URL for an RSS feed that you wish to convert to JSON.
        ###

        def set_RSSFeed(value)
          set_input("RSSFeed", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RSSToJSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RSSToJSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) The feed data in JSON format.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class RSSToJSON



    ##############################################################################
    #
    # TSVToJSON
    #
    # Converts a TSV formatted file to JSON.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TSVToJSON < Choreography

      ####
      #  Create a new instance of the TSVToJSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/TSVToJSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TSVToJSONInputSet
      ####
      def new_input_set()
        return TSVToJSONInputSet.new()
      end

      def make_result_set()
        return TSVToJSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TSVToJSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TSVToJSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TSVToJSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the TSV input for this Choreo. 
        # 
        # @param String - (required, multiline) The TSV file to convert to XML. Your TSV data must contain column names.
        ###

        def set_TSV(value)
          set_input("TSV", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TSVToJSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TSVToJSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "JSON" output from this Choreo execution
      	#
      	# @return String - (json) The JSON formatted data.
      	####
      	def get_JSON()
      	  return @outputs["JSON"]
      	end
      end

    end # class TSVToJSON



    ##############################################################################
    #
    # TSVToXML
    #
    # Converts a TSV formatted file to XML.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class TSVToXML < Choreography

      ####
      #  Create a new instance of the TSVToXML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/TSVToXML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return TSVToXMLInputSet
      ####
      def new_input_set()
        return TSVToXMLInputSet.new()
      end

      def make_result_set()
        return TSVToXMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = TSVToXMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the TSVToXML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class TSVToXMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the TSV input for this Choreo. 
        # 
        # @param String - (required, multiline) The TSV file to convert to XML. Your TSV data must contain column names.
        ###

        def set_TSV(value)
          set_input("TSV", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the TSVToXML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class TSVToXMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XML" output from this Choreo execution
      	#
      	# @return String - (xml) The XML formatted data.
      	####
      	def get_XML()
      	  return @outputs["XML"]
      	end
      end

    end # class TSVToXML



    ##############################################################################
    #
    # XLSToCSV
    #
    # Converts Excel (.xls) formatted data to CSV.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XLSToCSV < Choreography

      ####
      #  Create a new instance of the XLSToCSV Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XLSToCSV")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XLSToCSVInputSet
      ####
      def new_input_set()
        return XLSToCSVInputSet.new()
      end

      def make_result_set()
        return XLSToCSVResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XLSToCSVResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XLSToCSV
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XLSToCSVInputSet < Choreography::InputSet

        #### 
        # Set the value of the XLS input for this Choreo. 
        # 
        # @param String - (conditional, string) The base64-encoded contents of the Excel file that you want to convert to CSV format. Compatible with Excel 97-2003.
        ###

        def set_XLS(value)
          set_input("XLS", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) A path to an Excel file you've stored in the Vault. This can be used as an alternative to the ExcelFile input variable.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XLSToCSV Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XLSToCSVResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "CSV" output from this Choreo execution
      	#
      	# @return String - (string) The CSV formatted data.
      	####
      	def get_CSV()
      	  return @outputs["CSV"]
      	end
      end

    end # class XLSToCSV



    ##############################################################################
    #
    # XLSToXML
    #
    # Converts Excel (.xls) formatted data to XML.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XLSToXML < Choreography

      ####
      #  Create a new instance of the XLSToXML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XLSToXML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XLSToXMLInputSet
      ####
      def new_input_set()
        return XLSToXMLInputSet.new()
      end

      def make_result_set()
        return XLSToXMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XLSToXMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XLSToXML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XLSToXMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the XLS input for this Choreo. 
        # 
        # @param String - (conditional, string) The base64-encoded contents of the Excel file that you want to convert to XML. Compatible with Excel 97-2003.
        ###

        def set_XLS(value)
          set_input("XLS", value)
        end
        #### 
        # Set the value of the VaultFile input for this Choreo. 
        # 
        # @param TembooPath - (optional, vault file) A path to an Excel file that has been uploaded to the vault. You can use this input alias as an alternative to the ExcelFile input variable.
        ###

        def set_VaultFile(value)
          set_alias("VaultFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XLSToXML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XLSToXMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XML" output from this Choreo execution
      	#
      	# @return String - (xml) The data in XML format.
      	####
      	def get_XML()
      	  return @outputs["XML"]
      	end
      end

    end # class XLSToXML



    ##############################################################################
    #
    # XMLToCSV
    #
    # Converts an XML file to CSV format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XMLToCSV < Choreography

      ####
      #  Create a new instance of the XMLToCSV Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XMLToCSV")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XMLToCSVInputSet
      ####
      def new_input_set()
        return XMLToCSVInputSet.new()
      end

      def make_result_set()
        return XMLToCSVResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XMLToCSVResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XMLToCSV
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XMLToCSVInputSet < Choreography::InputSet

        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML file to convert to CSV data.
        ###

        def set_XML(value)
          set_input("XML", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) If your XML is not in "/rowset/row/column_name" format, specify a path to the rows. See documentation for examples.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XMLToCSV Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XMLToCSVResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "CSV" output from this Choreo execution
      	#
      	# @return String - (multiline) The CSV data generated from the XML input.
      	####
      	def get_CSV()
      	  return @outputs["CSV"]
      	end
      end

    end # class XMLToCSV



    ##############################################################################
    #
    # XMLToJSON
    #
    # Converts data from XML format to JSON format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XMLToJSON < Choreography

      ####
      #  Create a new instance of the XMLToJSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XMLToJSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XMLToJSONInputSet
      ####
      def new_input_set()
        return XMLToJSONInputSet.new()
      end

      def make_result_set()
        return XMLToJSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XMLToJSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XMLToJSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XMLToJSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML file that you want to convert to JSON format.
        ###

        def set_XML(value)
          set_input("XML", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XMLToJSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XMLToJSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "JSON" output from this Choreo execution
      	#
      	# @return String - (json) The converted data in JSON format.
      	####
      	def get_JSON()
      	  return @outputs["JSON"]
      	end
      end

    end # class XMLToJSON



    ##############################################################################
    #
    # XMLToTSV
    #
    # Converts an XML file to TSV format (TAB-separated values).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XMLToTSV < Choreography

      ####
      #  Create a new instance of the XMLToTSV Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XMLToTSV")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XMLToTSVInputSet
      ####
      def new_input_set()
        return XMLToTSVInputSet.new()
      end

      def make_result_set()
        return XMLToTSVResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XMLToTSVResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XMLToTSV
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XMLToTSVInputSet < Choreography::InputSet

        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML file to convert to TSV data.
        ###

        def set_XML(value)
          set_input("XML", value)
        end
        #### 
        # Set the value of the Path input for this Choreo. 
        # 
        # @param String - (optional, string) If your XML is not in "/rowset/row/column_name" format, specify a path to the rows. See documentation for examples.
        ###

        def set_Path(value)
          set_input("Path", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XMLToTSV Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XMLToTSVResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "TSV" output from this Choreo execution
      	#
      	# @return String - (multiline) The tab-separated data generated from the XML input.
      	####
      	def get_TSV()
      	  return @outputs["TSV"]
      	end
      end

    end # class XMLToTSV



    ##############################################################################
    #
    # XMLToXLS
    #
    # Converts an XML file to a Base64 encoded Excel file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XMLToXLS < Choreography

      ####
      #  Create a new instance of the XMLToXLS Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/DataConversions/XMLToXLS")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XMLToXLSInputSet
      ####
      def new_input_set()
        return XMLToXLSInputSet.new()
      end

      def make_result_set()
        return XMLToXLSResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XMLToXLSResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XMLToXLS
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XMLToXLSInputSet < Choreography::InputSet

        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML file you want to convert to XLS format. See documentation for information on the required XML schema.
        ###

        def set_XML(value)
          set_input("XML", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XMLToXLS Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XMLToXLSResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "XLS" output from this Choreo execution
      	#
      	# @return String - The Base64 encoded Excel data .
      	####
      	def get_XLS()
      	  return @outputs["XLS"]
      	end
      end

    end # class XMLToXLS




  end # module DataConversions

  module Dates



    ##############################################################################
    #
    # GetDate
    #
    # Formats a specified timestamp, or generates the current date in a desired format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetDate < Choreography

      ####
      #  Create a new instance of the GetDate Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Dates/GetDate")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetDateInputSet
      ####
      def new_input_set()
        return GetDateInputSet.new()
      end

      def make_result_set()
        return GetDateResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetDateResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetDate
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetDateInputSet < Choreography::InputSet

        #### 
        # Set the value of the AddDays input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of days to the specified date serial number. A negative number will subtract.
        ###

        def set_AddDays(value)
          set_input("AddDays", value)
        end
        #### 
        # Set the value of the AddHours input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of hours to the specified date serial number. A negative number will subtract.
        ###

        def set_AddHours(value)
          set_input("AddHours", value)
        end
        #### 
        # Set the value of the AddMinutes input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of minutes to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMinutes(value)
          set_input("AddMinutes", value)
        end
        #### 
        # Set the value of the AddMonths input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of months to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMonths(value)
          set_input("AddMonths", value)
        end
        #### 
        # Set the value of the AddSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of seconds to the specified date serial number. A negative number will subtract.
        ###

        def set_AddSeconds(value)
          set_input("AddSeconds", value)
        end
        #### 
        # Set the value of the AddYears input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of years to the specified date serial number. A negative number will subtract.
        ###

        def set_AddYears(value)
          set_input("AddYears", value)
        end
        #### 
        # Set the value of the Format input for this Choreo. 
        # 
        # @param String - (conditional, string) The format that the timestamp should be in. Java SimpleDateFormat conventions are supported. Defaults to "yyyy-MM-dd HH:mm:ss".
        ###

        def set_Format(value)
          set_input("Format", value)
        end
        #### 
        # Set the value of the LocaleCountry input for this Choreo. 
        # 
        # @param String - (optional, string) An ISO country code to specify locale.
        ###

        def set_LocaleCountry(value)
          set_input("LocaleCountry", value)
        end
        #### 
        # Set the value of the LocaleLanguage input for this Choreo. 
        # 
        # @param String - (optional, string) An ISO language code to specify locale.
        ###

        def set_LocaleLanguage(value)
          set_input("LocaleLanguage", value)
        end
        #### 
        # Set the value of the LocaleVariant input for this Choreo. 
        # 
        # @param String - (optional, string) A local variant code such as "NY" to add additional context for a locale.
        ###

        def set_LocaleVariant(value)
          set_input("LocaleVariant", value)
        end
        #### 
        # Set the value of the SetDay input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the day of month (1-31) of the specified date serial number.
        ###

        def set_SetDay(value)
          set_input("SetDay", value)
        end
        #### 
        # Set the value of the SetHour input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the hours (0-23) of the specified date serial number.
        ###

        def set_SetHour(value)
          set_input("SetHour", value)
        end
        #### 
        # Set the value of the SetMinute input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the minutes (0-59) of the specified date serial number.
        ###

        def set_SetMinute(value)
          set_input("SetMinute", value)
        end
        #### 
        # Set the value of the SetMonth input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the month (1-12) of the specified date serial number.
        ###

        def set_SetMonth(value)
          set_input("SetMonth", value)
        end
        #### 
        # Set the value of the SetSecond input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the seconds (0-59) of the specified date serial number.
        ###

        def set_SetSecond(value)
          set_input("SetSecond", value)
        end
        #### 
        # Set the value of the SetYear input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the year (such as 1989) of the specified date serial number.
        ###

        def set_SetYear(value)
          set_input("SetYear", value)
        end
        #### 
        # Set the value of the TimeZone input for this Choreo. 
        # 
        # @param String - (optional, string) The timezone to use for the date formatting function. Defaults to UTC.
        ###

        def set_TimeZone(value)
          set_input("TimeZone", value)
        end
        #### 
        # Set the value of the Timestamp input for this Choreo. 
        # 
        # @param String - (conditional, date) A number representing the desired formatted date and time, expressed as the number of milliseconds since January 1, 1970 (epoch time). If not provided, this defaults to NOW().
        ###

        def set_Timestamp(value)
          set_input("Timestamp", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetDate Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetDateResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "FormattedDate" output from this Choreo execution
      	#
      	# @return String - (date) The formatted version of the timestamp.
      	####
      	def get_FormattedDate()
      	  return @outputs["FormattedDate"]
      	end
      end

    end # class GetDate



    ##############################################################################
    #
    # GetDateDifference
    #
    # Returns the difference between two specified dates, expressed as the number of milliseconds since January 1, 1970 (epoch time).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetDateDifference < Choreography

      ####
      #  Create a new instance of the GetDateDifference Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Dates/GetDateDifference")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetDateDifferenceInputSet
      ####
      def new_input_set()
        return GetDateDifferenceInputSet.new()
      end

      def make_result_set()
        return GetDateDifferenceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetDateDifferenceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetDateDifference
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetDateDifferenceInputSet < Choreography::InputSet

        #### 
        # Set the value of the EarlierDate input for this Choreo. 
        # 
        # @param String - (required, date) The earlier date to use for the date comparision (e.g., March 2, 2014).
        ###

        def set_EarlierDate(value)
          set_input("EarlierDate", value)
        end
        #### 
        # Set the value of the LaterDate input for this Choreo. 
        # 
        # @param String - (required, date) The later date to use for the date comparision (e.g., March 3, 2014).
        ###

        def set_LaterDate(value)
          set_input("LaterDate", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetDateDifference Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetDateDifferenceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Difference" output from this Choreo execution
      	#
      	# @return String - (integer) The difference between two specified dates, expressed as the number of milliseconds since January 1, 1970 (epoch time). 
      	####
      	def get_Difference()
      	  return @outputs["Difference"]
      	end
      end

    end # class GetDateDifference



    ##############################################################################
    #
    # GetTimestamp
    #
    # Returns the current date and time, expressed as seconds or milliseconds since January 1, 1970 (epoch time).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTimestamp < Choreography

      ####
      #  Create a new instance of the GetTimestamp Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Dates/GetTimestamp")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTimestampInputSet
      ####
      def new_input_set()
        return GetTimestampInputSet.new()
      end

      def make_result_set()
        return GetTimestampResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTimestampResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTimestamp
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTimestampInputSet < Choreography::InputSet

        #### 
        # Set the value of the AddDays input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of days to the specified date serial number. A negative number will subtract.
        ###

        def set_AddDays(value)
          set_input("AddDays", value)
        end
        #### 
        # Set the value of the AddHours input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of hours to the specified date serial number. A negative number will subtract.
        ###

        def set_AddHours(value)
          set_input("AddHours", value)
        end
        #### 
        # Set the value of the AddMinutes input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of minutes to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMinutes(value)
          set_input("AddMinutes", value)
        end
        #### 
        # Set the value of the AddMonths input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of months to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMonths(value)
          set_input("AddMonths", value)
        end
        #### 
        # Set the value of the AddSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of seconds to the specified date serial number. A negative number will subtract.
        ###

        def set_AddSeconds(value)
          set_input("AddSeconds", value)
        end
        #### 
        # Set the value of the AddYears input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of years to the specified date serial number. A negative number will subtract.
        ###

        def set_AddYears(value)
          set_input("AddYears", value)
        end
        #### 
        # Set the value of the Granularity input for this Choreo. 
        # 
        # @param String - (optional, string) Set to "seconds" to return the number of seconds since the epoch. Defaults to "milliseconds".
        ###

        def set_Granularity(value)
          set_input("Granularity", value)
        end
        #### 
        # Set the value of the SetDay input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the day of month (1-31) of the specified date serial number.
        ###

        def set_SetDay(value)
          set_input("SetDay", value)
        end
        #### 
        # Set the value of the SetHour input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the hours (0-23) of the specified date serial number.
        ###

        def set_SetHour(value)
          set_input("SetHour", value)
        end
        #### 
        # Set the value of the SetMinute input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the minutes (0-59) of the specified date serial number.
        ###

        def set_SetMinute(value)
          set_input("SetMinute", value)
        end
        #### 
        # Set the value of the SetMonth input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the month (1-12) of the specified date serial number.
        ###

        def set_SetMonth(value)
          set_input("SetMonth", value)
        end
        #### 
        # Set the value of the SetSecond input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the seconds (0-59) of the specified date serial number.
        ###

        def set_SetSecond(value)
          set_input("SetSecond", value)
        end
        #### 
        # Set the value of the SetYear input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the year (such as 1989) of the specified date serial number.
        ###

        def set_SetYear(value)
          set_input("SetYear", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTimestamp Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTimestampResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Timestamp" output from this Choreo execution
      	#
      	# @return String - (date) A the current timestamp, expressed as the number of seconds or milliseconds since January 1, 1970 (epoch time). The Granularity input is used to indicate seconds or milliseconds.
      	####
      	def get_Timestamp()
      	  return @outputs["Timestamp"]
      	end
      end

    end # class GetTimestamp



    ##############################################################################
    #
    # GetTimestampFromDateParameters
    #
    # Returns the specified date parameters, expressed as the number of seconds or milliseconds since January 1, 1970 (epoch time).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTimestampFromDateParameters < Choreography

      ####
      #  Create a new instance of the GetTimestampFromDateParameters Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Dates/GetTimestampFromDateParameters")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTimestampFromDateParametersInputSet
      ####
      def new_input_set()
        return GetTimestampFromDateParametersInputSet.new()
      end

      def make_result_set()
        return GetTimestampFromDateParametersResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTimestampFromDateParametersResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTimestampFromDateParameters
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTimestampFromDateParametersInputSet < Choreography::InputSet

        #### 
        # Set the value of the Day input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) Sets the day (1-31) of the timestamp.
        ###

        def set_Day(value)
          set_input("Day", value)
        end
        #### 
        # Set the value of the Granularity input for this Choreo. 
        # 
        # @param String - (optional, string) Set to "seconds" to return the number of seconds since the epoch. Defaults to "milliseconds".
        ###

        def set_Granularity(value)
          set_input("Granularity", value)
        end
        #### 
        # Set the value of the Hour input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the hours (0-23) of the timestamp.
        ###

        def set_Hour(value)
          set_input("Hour", value)
        end
        #### 
        # Set the value of the Milliseconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the milliseconds (0-999) of the timestamp.
        ###

        def set_Milliseconds(value)
          set_input("Milliseconds", value)
        end
        #### 
        # Set the value of the Minute input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the minutes (0-59) of the timestamp.
        ###

        def set_Minute(value)
          set_input("Minute", value)
        end
        #### 
        # Set the value of the Month input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) Sets the month (1-12) of the timestamp.
        ###

        def set_Month(value)
          set_input("Month", value)
        end
        #### 
        # Set the value of the Second input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the seconds (0-59) of the timestamp.
        ###

        def set_Second(value)
          set_input("Second", value)
        end
        #### 
        # Set the value of the Year input for this Choreo. 
        # 
        # @param Integer - (conditional, integer) Sets the year of the timestamp.
        ###

        def set_Year(value)
          set_input("Year", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTimestampFromDateParameters Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTimestampFromDateParametersResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Timestamp" output from this Choreo execution
      	#
      	# @return String - (date) A number representing the specified date and time, expressed as the number of seconds or milliseconds since January 1, 1970. The Granularity input is used to indicate seconds or milliseconds.
      	####
      	def get_Timestamp()
      	  return @outputs["Timestamp"]
      	end
      end

    end # class GetTimestampFromDateParameters



    ##############################################################################
    #
    # GetTimestampFromDateString
    #
    # Returns the the specified date string, expressed as seconds or milliseconds since January 1, 1970 (epoch time).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTimestampFromDateString < Choreography

      ####
      #  Create a new instance of the GetTimestampFromDateString Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Dates/GetTimestampFromDateString")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTimestampFromDateStringInputSet
      ####
      def new_input_set()
        return GetTimestampFromDateStringInputSet.new()
      end

      def make_result_set()
        return GetTimestampFromDateStringResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTimestampFromDateStringResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTimestampFromDateString
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTimestampFromDateStringInputSet < Choreography::InputSet

        #### 
        # Set the value of the AddDays input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of days to the specified date serial number. A negative number will subtract.
        ###

        def set_AddDays(value)
          set_input("AddDays", value)
        end
        #### 
        # Set the value of the AddHours input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of hours to the specified date serial number. A negative number will subtract.
        ###

        def set_AddHours(value)
          set_input("AddHours", value)
        end
        #### 
        # Set the value of the AddMinutes input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of minutes to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMinutes(value)
          set_input("AddMinutes", value)
        end
        #### 
        # Set the value of the AddMonths input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of months to the specified date serial number. A negative number will subtract.
        ###

        def set_AddMonths(value)
          set_input("AddMonths", value)
        end
        #### 
        # Set the value of the AddSeconds input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of seconds to the specified date serial number. A negative number will subtract.
        ###

        def set_AddSeconds(value)
          set_input("AddSeconds", value)
        end
        #### 
        # Set the value of the AddYears input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Adds the specified number of years to the specified date serial number. A negative number will subtract.
        ###

        def set_AddYears(value)
          set_input("AddYears", value)
        end
        #### 
        # Set the value of the Date input for this Choreo. 
        # 
        # @param String - (required, string) A date string to convert to a timestamp (e.g., March 2, 2014).
        ###

        def set_Date(value)
          set_input("Date", value)
        end
        #### 
        # Set the value of the Granularity input for this Choreo. 
        # 
        # @param String - (optional, string) Set to "seconds" to return the number of seconds since the epoch. Defaults to "milliseconds".
        ###

        def set_Granularity(value)
          set_input("Granularity", value)
        end
        #### 
        # Set the value of the SetDay input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the day of month (1-31) of the specified date serial number.
        ###

        def set_SetDay(value)
          set_input("SetDay", value)
        end
        #### 
        # Set the value of the SetHour input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the hours (0-23) of the specified date serial number.
        ###

        def set_SetHour(value)
          set_input("SetHour", value)
        end
        #### 
        # Set the value of the SetMinute input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the minutes (0-59) of the specified date serial number.
        ###

        def set_SetMinute(value)
          set_input("SetMinute", value)
        end
        #### 
        # Set the value of the SetMonth input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the month (1-12) of the specified date serial number.
        ###

        def set_SetMonth(value)
          set_input("SetMonth", value)
        end
        #### 
        # Set the value of the SetSecond input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the seconds (0-59) of the specified date serial number.
        ###

        def set_SetSecond(value)
          set_input("SetSecond", value)
        end
        #### 
        # Set the value of the SetYear input for this Choreo. 
        # 
        # @param Integer - (optional, integer) Sets the year (such as 1989) of the specified date serial number.
        ###

        def set_SetYear(value)
          set_input("SetYear", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTimestampFromDateString Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTimestampFromDateStringResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Timestamp" output from this Choreo execution
      	#
      	# @return String - (date) A the current timestamp, expressed as the number of seconds or milliseconds since January 1, 1970 (epoch time). The Granularity input is used to indicate seconds or milliseconds.
      	####
      	def get_Timestamp()
      	  return @outputs["Timestamp"]
      	end
      end

    end # class GetTimestampFromDateString




  end # module Dates

  module Email



    ##############################################################################
    #
    # SendEmail
    #
    # Sends an email using a specified email server.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SendEmail < Choreography

      ####
      #  Create a new instance of the SendEmail Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Email/SendEmail")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SendEmailInputSet
      ####
      def new_input_set()
        return SendEmailInputSet.new()
      end

      def make_result_set()
        return SendEmailResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SendEmailResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SendEmail
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SendEmailInputSet < Choreography::InputSet

        #### 
        # Set the value of the Attachment input for this Choreo. 
        # 
        # @param String - (optional, string) The Base64 encoded contents of the file to attach to the email.  Use this instead of AttachmentURL.
        ###

        def set_Attachment(value)
          set_input("Attachment", value)
        end
        #### 
        # Set the value of the AttachmentName input for this Choreo. 
        # 
        # @param String - (optional, string) The name of the file to attach to the email.
        ###

        def set_AttachmentName(value)
          set_input("AttachmentName", value)
        end
        #### 
        # Set the value of the AttachmentURL input for this Choreo. 
        # 
        # @param String - (optional, string) URL of a hosted file that you wish to add as an attachment.  Use this instead of a normal Attachment.
        ###

        def set_AttachmentURL(value)
          set_input("AttachmentURL", value)
        end
        #### 
        # Set the value of the BCC input for this Choreo. 
        # 
        # @param String - (optional, string) An email address to BCC on the email you're sending. Can be a comma separated list of email addresses.
        ###

        def set_BCC(value)
          set_input("BCC", value)
        end
        #### 
        # Set the value of the CC input for this Choreo. 
        # 
        # @param String - (optional, string) An email address to CC on the email you're sending. Can be a comma separated list of email addresses.
        ###

        def set_CC(value)
          set_input("CC", value)
        end
        #### 
        # Set the value of the FromAddress input for this Choreo. 
        # 
        # @param String - (conditional, string) The name and email address that the message is being sent from.
        ###

        def set_FromAddress(value)
          set_input("FromAddress", value)
        end
        #### 
        # Set the value of the MessageBody input for this Choreo. 
        # 
        # @param String - (required, string) The message body for the email.
        ###

        def set_MessageBody(value)
          set_input("MessageBody", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, password) The password for your email account.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the Port input for this Choreo. 
        # 
        # @param Integer - (required, integer) Specify the port number (i.e. 25 or 465).
        ###

        def set_Port(value)
          set_input("Port", value)
        end
        #### 
        # Set the value of the Server input for this Choreo. 
        # 
        # @param String - (required, string) The name or IP address of the email server.
        ###

        def set_Server(value)
          set_input("Server", value)
        end
        #### 
        # Set the value of the Subject input for this Choreo. 
        # 
        # @param String - (required, string) The subject line of the email.
        ###

        def set_Subject(value)
          set_input("Subject", value)
        end
        #### 
        # Set the value of the ToAddress input for this Choreo. 
        # 
        # @param String - (required, string) The email address that you want to send an email to. Can be a comma separated list of email addresses.
        ###

        def set_ToAddress(value)
          set_input("ToAddress", value)
        end
        #### 
        # Set the value of the UseSSL input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Set to 1 to connect over SSL. Set to 0 for no SSL. Defaults to 1.
        ###

        def set_UseSSL(value)
          set_input("UseSSL", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (required, string) Your username for your email account.
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SendEmail Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SendEmailResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Success" output from this Choreo execution
      	#
      	# @return String - (boolean) Indicates the result of the SMTP operation. The value will be "true" for a successful request.
      	####
      	def get_Success()
      	  return @outputs["Success"]
      	end
      end

    end # class SendEmail




  end # module Email

  module Encoding



    ##############################################################################
    #
    # Base64Decode
    #
    # Returns the specified Base64 encoded string as decoded text.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Base64Decode < Choreography

      ####
      #  Create a new instance of the Base64Decode Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/Base64Decode")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return Base64DecodeInputSet
      ####
      def new_input_set()
        return Base64DecodeInputSet.new()
      end

      def make_result_set()
        return Base64DecodeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = Base64DecodeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Base64Decode
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class Base64DecodeInputSet < Choreography::InputSet

        #### 
        # Set the value of the Base64EncodedText input for this Choreo. 
        # 
        # @param String - (required, string) The Base64 encoded text to decode. Note that Base64 encoded binary data is not allowed.
        ###

        def set_Base64EncodedText(value)
          set_input("Base64EncodedText", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Base64Decode Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class Base64DecodeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Text" output from this Choreo execution
      	#
      	# @return String - (string) The decoded text.
      	####
      	def get_Text()
      	  return @outputs["Text"]
      	end
      end

    end # class Base64Decode



    ##############################################################################
    #
    # Base64Encode
    #
    # Returns the specified text or file as a Base64 encoded string.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Base64Encode < Choreography

      ####
      #  Create a new instance of the Base64Encode Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/Base64Encode")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return Base64EncodeInputSet
      ####
      def new_input_set()
        return Base64EncodeInputSet.new()
      end

      def make_result_set()
        return Base64EncodeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = Base64EncodeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Base64Encode
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class Base64EncodeInputSet < Choreography::InputSet

        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (conditional, string) The text that should be Base64 encoded. Required unless providing a value for the URL input.
        ###

        def set_Text(value)
          set_input("Text", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (conditional, string) A URL to a hosted file that should be Base64 encoded. Required unless providing a value for the Text input.
        ###

        def set_URL(value)
          set_input("URL", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Base64Encode Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class Base64EncodeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Base64EncodedText" output from this Choreo execution
      	#
      	# @return String - (string) The Base64 encoded text.
      	####
      	def get_Base64EncodedText()
      	  return @outputs["Base64EncodedText"]
      	end
      end

    end # class Base64Encode



    ##############################################################################
    #
    # HTMLEscape
    #
    # Replaces HTML markup characters in the specified text with equivalent character entity names. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class HTMLEscape < Choreography

      ####
      #  Create a new instance of the HTMLEscape Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/HTMLEscape")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return HTMLEscapeInputSet
      ####
      def new_input_set()
        return HTMLEscapeInputSet.new()
      end

      def make_result_set()
        return HTMLEscapeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = HTMLEscapeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the HTMLEscape
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class HTMLEscapeInputSet < Choreography::InputSet

        #### 
        # Set the value of the UnescapedHTML input for this Choreo. 
        # 
        # @param String - (required, string) The HTML that needs to be escaped.
        ###

        def set_UnescapedHTML(value)
          set_input("UnescapedHTML", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the HTMLEscape Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class HTMLEscapeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "EscapedHTML" output from this Choreo execution
      	#
      	# @return String - (string) The escaped HTML.
      	####
      	def get_EscapedHTML()
      	  return @outputs["EscapedHTML"]
      	end
      end

    end # class HTMLEscape



    ##############################################################################
    #
    # HTMLUnescape
    #
    # Replaces character entity names in the specified text with equivalent HTML markup characters.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class HTMLUnescape < Choreography

      ####
      #  Create a new instance of the HTMLUnescape Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/HTMLUnescape")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return HTMLUnescapeInputSet
      ####
      def new_input_set()
        return HTMLUnescapeInputSet.new()
      end

      def make_result_set()
        return HTMLUnescapeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = HTMLUnescapeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the HTMLUnescape
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class HTMLUnescapeInputSet < Choreography::InputSet

        #### 
        # Set the value of the EscapedHTML input for this Choreo. 
        # 
        # @param String - (required, string) The escaped HTML that should be unescaped.
        ###

        def set_EscapedHTML(value)
          set_input("EscapedHTML", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the HTMLUnescape Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class HTMLUnescapeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "UnescapedHTML" output from this Choreo execution
      	#
      	# @return String - (string) The unescaped HTML.
      	####
      	def get_UnescapedHTML()
      	  return @outputs["UnescapedHTML"]
      	end
      end

    end # class HTMLUnescape



    ##############################################################################
    #
    # URLDecode
    #
    # Removes URL encoding from the specified text string.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class URLDecode < Choreography

      ####
      #  Create a new instance of the URLDecode Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/URLDecode")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return URLDecodeInputSet
      ####
      def new_input_set()
        return URLDecodeInputSet.new()
      end

      def make_result_set()
        return URLDecodeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = URLDecodeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the URLDecode
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class URLDecodeInputSet < Choreography::InputSet

        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text that should be URL decoded.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the URLDecode Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class URLDecodeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URLDecodedText" output from this Choreo execution
      	#
      	# @return String - (string) The URL decoded text.
      	####
      	def get_URLDecodedText()
      	  return @outputs["URLDecodedText"]
      	end
      end

    end # class URLDecode



    ##############################################################################
    #
    # URLEncode
    #
    # Returns the specified text string in the application/x-www-form-urlencoded format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class URLEncode < Choreography

      ####
      #  Create a new instance of the URLEncode Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Encoding/URLEncode")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return URLEncodeInputSet
      ####
      def new_input_set()
        return URLEncodeInputSet.new()
      end

      def make_result_set()
        return URLEncodeResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = URLEncodeResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the URLEncode
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class URLEncodeInputSet < Choreography::InputSet

        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text that should be URL encoded.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the URLEncode Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class URLEncodeResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "URLEncodedText" output from this Choreo execution
      	#
      	# @return String - (string) The URL encoded text.
      	####
      	def get_URLEncodedText()
      	  return @outputs["URLEncodedText"]
      	end
      end

    end # class URLEncode




  end # module Encoding

  module Finding



    ##############################################################################
    #
    # FindSubstring
    #
    # Finds all occurrences of a specified substring and returns the substring positions as a JSON array.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class FindSubstring < Choreography

      ####
      #  Create a new instance of the FindSubstring Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Finding/FindSubstring")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return FindSubstringInputSet
      ####
      def new_input_set()
        return FindSubstringInputSet.new()
      end

      def make_result_set()
        return FindSubstringResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = FindSubstringResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the FindSubstring
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class FindSubstringInputSet < Choreography::InputSet

        #### 
        # Set the value of the CaseSensitive input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to true, the search will be case-sensitive. Defaults to false indicating a case-insensitive search.
        ###

        def set_CaseSensitive(value)
          set_input("CaseSensitive", value)
        end
        #### 
        # Set the value of the StartNumber input for this Choreo. 
        # 
        # @param String - (optional, string) The character position at which to begin the search. Defaults to 1.
        ###

        def set_StartNumber(value)
          set_input("StartNumber", value)
        end
        #### 
        # Set the value of the Substring input for this Choreo. 
        # 
        # @param String - (required, string) The sub-string to search within the specified text (searching from left to right).
        ###

        def set_Substring(value)
          set_input("Substring", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text to search for a sub-string.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the FindSubstring Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class FindSubstringResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Count" output from this Choreo execution
      	#
      	# @return String - (integer) The count of sub-strings found.
      	####
      	def get_Count()
      	  return @outputs["Count"]
      	end
      	####
      	# Retrieve the value for the "Positions" output from this Choreo execution
      	#
      	# @return String - (json) The positions of the sub-strings that were found in the search.
      	####
      	def get_Positions()
      	  return @outputs["Positions"]
      	end
      end

    end # class FindSubstring



    ##############################################################################
    #
    # RegexMatch
    #
    # Returns the first substring that matches the specified regular expression pattern in the specified string.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RegexMatch < Choreography

      ####
      #  Create a new instance of the RegexMatch Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Finding/RegexMatch")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RegexMatchInputSet
      ####
      def new_input_set()
        return RegexMatchInputSet.new()
      end

      def make_result_set()
        return RegexMatchResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RegexMatchResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RegexMatch
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RegexMatchInputSet < Choreography::InputSet

        #### 
        # Set the value of the Pattern input for this Choreo. 
        # 
        # @param String - (conditional, string) A regular expression.
        ###

        def set_Pattern(value)
          set_input("Pattern", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (conditional, string) The text on which to perform a regex match.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RegexMatch Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RegexMatchResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - (string) The result of the match.
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class RegexMatch




  end # module Finding

  module Formatting



    ##############################################################################
    #
    # RemoveWhiteSpace
    #
    # Returns the specified formatted text as a compact string with no new lines, tabs, or preceding/trailing white space.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RemoveWhiteSpace < Choreography

      ####
      #  Create a new instance of the RemoveWhiteSpace Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Formatting/RemoveWhiteSpace")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RemoveWhiteSpaceInputSet
      ####
      def new_input_set()
        return RemoveWhiteSpaceInputSet.new()
      end

      def make_result_set()
        return RemoveWhiteSpaceResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RemoveWhiteSpaceResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RemoveWhiteSpace
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RemoveWhiteSpaceInputSet < Choreography::InputSet

        #### 
        # Set the value of the FormattedText input for this Choreo. 
        # 
        # @param String - (required, multiline) The formatted text that should have line breaks and tabs removed.
        ###

        def set_FormattedText(value)
          set_input("FormattedText", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RemoveWhiteSpace Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RemoveWhiteSpaceResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "CompactText" output from this Choreo execution
      	#
      	# @return String - (string) 
      	####
      	def get_CompactText()
      	  return @outputs["CompactText"]
      	end
      end

    end # class RemoveWhiteSpace




  end # module Formatting

  module HTTP



    ##############################################################################
    #
    # Delete
    #
    # Generates a HTTP DELETE request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Delete < Choreography

      ####
      #  Create a new instance of the Delete Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/HTTP/Delete")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteInputSet
      ####
      def new_input_set()
        return DeleteInputSet.new()
      end

      def make_result_set()
        return DeleteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Delete
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteInputSet < Choreography::InputSet

        #### 
        # Set the value of the Debug input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true", the HTTP debug log will be returned.
        ###

        def set_Debug(value)
          set_input("Debug", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (optional, password) A valid password. This is used if the request required basic authentication.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the RequestHeaders input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the HTTP request headers.
        ###

        def set_RequestHeaders(value)
          set_input("RequestHeaders", value)
        end
        #### 
        # Set the value of the RequestParameters input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the url string as HTTP parameters.
        ###

        def set_RequestParameters(value)
          set_input("RequestParameters", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The base URL for the request (including http:// or https://).
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (optional, string) A valid username. This is used if the request required basic authentication.
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Delete Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HTTPLog" output from this Choreo execution
      	#
      	# @return String - (string) A debug log for the http request that was sent. This is only returned when Debug is set to "true".
      	####
      	def get_HTTPLog()
      	  return @outputs["HTTPLog"]
      	end
      	####
      	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code.
      	####
      	def get_ResponseStatusCode()
      	  return @outputs["ResponseStatusCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from the server.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Delete



    ##############################################################################
    #
    # Get
    #
    # Generates a HTTP GET request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Get < Choreography

      ####
      #  Create a new instance of the Get Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/HTTP/Get")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetInputSet
      ####
      def new_input_set()
        return GetInputSet.new()
      end

      def make_result_set()
        return GetResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Get
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetInputSet < Choreography::InputSet

        #### 
        # Set the value of the Debug input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true", the HTTP debug log will be returned.
        ###

        def set_Debug(value)
          set_input("Debug", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (optional, password) A valid password. This is used if the request required basic authentication.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the RequestHeaders input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the HTTP request headers.
        ###

        def set_RequestHeaders(value)
          set_input("RequestHeaders", value)
        end
        #### 
        # Set the value of the RequestParameters input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the url string as http parameters.
        ###

        def set_RequestParameters(value)
          set_input("RequestParameters", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The base URL for the request (including http:// or https://).
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (optional, string) A valid username. This is used if the request required basic authentication.
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Get Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HTTPLog" output from this Choreo execution
      	#
      	# @return String - (string) A debug log for the http request that was sent. This is only returned when Debug is set to "true".
      	####
      	def get_HTTPLog()
      	  return @outputs["HTTPLog"]
      	end
      	####
      	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code.
      	####
      	def get_ResponseStatusCode()
      	  return @outputs["ResponseStatusCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from the server.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Get



    ##############################################################################
    #
    # Post
    #
    # Generates a HTTP POST request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Post < Choreography

      ####
      #  Create a new instance of the Post Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/HTTP/Post")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PostInputSet
      ####
      def new_input_set()
        return PostInputSet.new()
      end

      def make_result_set()
        return PostResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PostResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Post
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PostInputSet < Choreography::InputSet

        #### 
        # Set the value of the RequestBody input for this Choreo. 
        # 
        # @param String - (optional, multiline) The request body for the POST request.
        ###

        def set_RequestBody(value)
          set_input("RequestBody", value)
        end
        #### 
        # Set the value of the Debug input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true", the HTTP debug log will be returned.
        ###

        def set_Debug(value)
          set_input("Debug", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (optional, password) A valid password. This is used if the request required basic authentication.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the RequestHeaders input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the HTTP request headers.
        ###

        def set_RequestHeaders(value)
          set_input("RequestHeaders", value)
        end
        #### 
        # Set the value of the RequestParameters input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the url string as http parameters.
        ###

        def set_RequestParameters(value)
          set_input("RequestParameters", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The base URL for the request (including http:// or https://).
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (optional, string) A valid username. This is used if the request required basic authentication.
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Post Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PostResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HTTPLog" output from this Choreo execution
      	#
      	# @return String - (string) A debug log for the http request that was sent. This is only returned when Debug is set to "true".
      	####
      	def get_HTTPLog()
      	  return @outputs["HTTPLog"]
      	end
      	####
      	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code.
      	####
      	def get_ResponseStatusCode()
      	  return @outputs["ResponseStatusCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from the server.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Post



    ##############################################################################
    #
    # Put
    #
    # Generates a HTTP PUT request.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Put < Choreography

      ####
      #  Create a new instance of the Put Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/HTTP/Put")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PutInputSet
      ####
      def new_input_set()
        return PutInputSet.new()
      end

      def make_result_set()
        return PutResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PutResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Put
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PutInputSet < Choreography::InputSet

        #### 
        # Set the value of the RequestBody input for this Choreo. 
        # 
        # @param String - (optional, multiline) The request body for the PUT request.
        ###

        def set_RequestBody(value)
          set_input("RequestBody", value)
        end
        #### 
        # Set the value of the Debug input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) When set to "true", the HTTP debug log will be returned.
        ###

        def set_Debug(value)
          set_input("Debug", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (optional, password) A valid password. This is used if the request required basic authentication.
        ###

        def set_Password(value)
          set_input("Password", value)
        end
        #### 
        # Set the value of the RequestHeaders input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the HTTP request headers.
        ###

        def set_RequestHeaders(value)
          set_input("RequestHeaders", value)
        end
        #### 
        # Set the value of the RequestParameters input for this Choreo. 
        # 
        # @param String - (optional, json) A JSON object containing up to 10 key/value pairs that will be mapped to the url string as HTTP parameters.
        ###

        def set_RequestParameters(value)
          set_input("RequestParameters", value)
        end
        #### 
        # Set the value of the URL input for this Choreo. 
        # 
        # @param String - (required, string) The base URL for the request (including http:// or https://).
        ###

        def set_URL(value)
          set_input("URL", value)
        end
        #### 
        # Set the value of the Username input for this Choreo. 
        # 
        # @param String - (optional, string) A valid username. This is used if the request required basic authentication.
        ###

        def set_Username(value)
          set_input("Username", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Put Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PutResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HTTPLog" output from this Choreo execution
      	#
      	# @return String - (string) A debug log for the http request that was sent. This is only returned when Debug is set to "true".
      	####
      	def get_HTTPLog()
      	  return @outputs["HTTPLog"]
      	end
      	####
      	# Retrieve the value for the "ResponseStatusCode" output from this Choreo execution
      	#
      	# @return String - (integer) The response status code.
      	####
      	def get_ResponseStatusCode()
      	  return @outputs["ResponseStatusCode"]
      	end
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - The response from the server.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Put




  end # module HTTP

  module Hashing



    ##############################################################################
    #
    # Checksum
    #
    # Returns a checksum of the specified text calculated using the specified algorithm. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Checksum < Choreography

      ####
      #  Create a new instance of the Checksum Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Hashing/Checksum")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return ChecksumInputSet
      ####
      def new_input_set()
        return ChecksumInputSet.new()
      end

      def make_result_set()
        return ChecksumResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = ChecksumResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Checksum
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class ChecksumInputSet < Choreography::InputSet

        #### 
        # Set the value of the Algorithm input for this Choreo. 
        # 
        # @param String - (required, string) Algorithm used to calculate the checksum. Valid values are: FIX44,  MD5+BASE64, or MD5+HEX (the default). MD5+BASE64 and MD5+HEX return the result in Base64 and hexadecimal encoding, respectively.
        ###

        def set_Algorithm(value)
          set_input("Algorithm", value)
        end
        #### 
        # Set the value of the Base64DecodeValue input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) Setting this parameter to 1 indicates that the Text is Base64 encoded, and that the choreo should decode the value before calculating the checksum. Defaults to 0.
        ###

        def set_Base64DecodeValue(value)
          set_input("Base64DecodeValue", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text to return a checksum for.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Checksum Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class ChecksumResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Checksum" output from this Choreo execution
      	#
      	# @return String - (string) The checksum result.
      	####
      	def get_Checksum()
      	  return @outputs["Checksum"]
      	end
      end

    end # class Checksum



    ##############################################################################
    #
    # HmacSHA1
    #
    # Generates a SHA1-encrypted HMAC signature for the specified message text using the specified secret key.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class HmacSHA1 < Choreography

      ####
      #  Create a new instance of the HmacSHA1 Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Hashing/HmacSHA1")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return HmacSHA1InputSet
      ####
      def new_input_set()
        return HmacSHA1InputSet.new()
      end

      def make_result_set()
        return HmacSHA1ResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = HmacSHA1ResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the HmacSHA1
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class HmacSHA1InputSet < Choreography::InputSet

        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (required, string) The secret key used to generate the SHA1-encrypted HMAC signature.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text that should be SHA1-encrypted.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the HmacSHA1 Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class HmacSHA1ResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HmacSignature" output from this Choreo execution
      	#
      	# @return String - (string) The HMAC Signature for the specified string.
      	####
      	def get_HmacSignature()
      	  return @outputs["HmacSignature"]
      	end
      end

    end # class HmacSHA1



    ##############################################################################
    #
    # HmacSHA256
    #
    # Generates a SHA256-encrypted HMAC signature for the specified message text using the specified secret key.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class HmacSHA256 < Choreography

      ####
      #  Create a new instance of the HmacSHA256 Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Hashing/HmacSHA256")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return HmacSHA256InputSet
      ####
      def new_input_set()
        return HmacSHA256InputSet.new()
      end

      def make_result_set()
        return HmacSHA256ResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = HmacSHA256ResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the HmacSHA256
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class HmacSHA256InputSet < Choreography::InputSet

        #### 
        # Set the value of the Key input for this Choreo. 
        # 
        # @param String - (required, string) The secret key used to generate the SHA256-encrypted HMAC signature.
        ###

        def set_Key(value)
          set_input("Key", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) The text that should be SHA256-encrypted.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the HmacSHA256 Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class HmacSHA256ResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "HmacSignature" output from this Choreo execution
      	#
      	# @return String - (string) The HMAC Signature for the specified string.
      	####
      	def get_HmacSignature()
      	  return @outputs["HmacSignature"]
      	end
      end

    end # class HmacSHA256




  end # module Hashing

  module JSON



    ##############################################################################
    #
    # GetValuesFromJSON
    #
    # Searches for the specified property in the supplied JSON string.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetValuesFromJSON < Choreography

      ####
      #  Create a new instance of the GetValuesFromJSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/JSON/GetValuesFromJSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetValuesFromJSONInputSet
      ####
      def new_input_set()
        return GetValuesFromJSONInputSet.new()
      end

      def make_result_set()
        return GetValuesFromJSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetValuesFromJSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetValuesFromJSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetValuesFromJSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the JSON input for this Choreo. 
        # 
        # @param String - (required, json) JSON String to search.
        ###

        def set_JSON(value)
          set_input("JSON", value)
        end
        #### 
        # Set the value of the Property input for this Choreo. 
        # 
        # @param String - (required, string) Property to match in the specified JSON string.
        ###

        def set_Property(value)
          set_input("Property", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetValuesFromJSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetValuesFromJSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (json) Value(s) that match the property.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class GetValuesFromJSON




  end # module JSON

  module Numbers



    ##############################################################################
    #
    # GenerateRandom
    #
    # This choreo generates a random number in a variety of ranges. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GenerateRandom < Choreography

      ####
      #  Create a new instance of the GenerateRandom Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Numbers/GenerateRandom")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GenerateRandomInputSet
      ####
      def new_input_set()
        return GenerateRandomInputSet.new()
      end

      def make_result_set()
        return GenerateRandomResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GenerateRandomResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GenerateRandom
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GenerateRandomInputSet < Choreography::InputSet


      end

      ####
      # A ResultSet with methods tailored to the values returned by the GenerateRandom Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GenerateRandomResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "SignedDecimal" output from this Choreo execution
      	#
      	# @return String - (decimal) Signed Decimal in the range of  -0.5 to +0.5.
      	####
      	def get_SignedDecimal()
      	  return @outputs["SignedDecimal"]
      	end
      	####
      	# Retrieve the value for the "SignedInteger" output from this Choreo execution
      	#
      	# @return String - (integer) SIgned Integer in the range of -2147483648 through 2147483647.
      	####
      	def get_SignedInteger()
      	  return @outputs["SignedInteger"]
      	end
      	####
      	# Retrieve the value for the "UnsignedDecimal" output from this Choreo execution
      	#
      	# @return String - (decimal) Unsigned Decimal in the range of 0.0 to 1.0.
      	####
      	def get_UnsignedDecimal()
      	  return @outputs["UnsignedDecimal"]
      	end
      	####
      	# Retrieve the value for the "UnsignedInteger" output from this Choreo execution
      	#
      	# @return String - (integer) Unsigned integer in the range of 0 through 4294967295.
      	####
      	def get_UnsignedInteger()
      	  return @outputs["UnsignedInteger"]
      	end
      end

    end # class GenerateRandom




  end # module Numbers

  module Test



    ##############################################################################
    #
    # HelloWorld
    #
    # Allows you to run a simple test that outputs "Hello, world!" when executed.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class HelloWorld < Choreography

      ####
      #  Create a new instance of the HelloWorld Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Test/HelloWorld")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return HelloWorldInputSet
      ####
      def new_input_set()
        return HelloWorldInputSet.new()
      end

      def make_result_set()
        return HelloWorldResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = HelloWorldResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the HelloWorld
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class HelloWorldInputSet < Choreography::InputSet

        #### 
        # Set the value of the Value input for this Choreo. 
        # 
        # @param String - (conditional, string) An optional test value to pass into the result message.
        ###

        def set_Value(value)
          set_input("Value", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the HelloWorld Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class HelloWorldResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - (string) Contains a sample Choreo output. If no input is provided, the result will be "Hello, world!". When passing an input value, the result will be "Hello, {Value}!".
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class HelloWorld




  end # module Test

  module Text



    ##############################################################################
    #
    # GenerateGUID
    #
    # Obtain a unique, randomly generated ID or GUID (Globally Unique Identifier).
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GenerateGUID < Choreography

      ####
      #  Create a new instance of the GenerateGUID Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/GenerateGUID")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GenerateGUIDInputSet
      ####
      def new_input_set()
        return GenerateGUIDInputSet.new()
      end

      def make_result_set()
        return GenerateGUIDResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GenerateGUIDResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GenerateGUID
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GenerateGUIDInputSet < Choreography::InputSet


      end

      ####
      # A ResultSet with methods tailored to the values returned by the GenerateGUID Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GenerateGUIDResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "GUID" output from this Choreo execution
      	#
      	# @return String - (string) The generated GUID.
      	####
      	def get_GUID()
      	  return @outputs["GUID"]
      	end
      end

    end # class GenerateGUID



    ##############################################################################
    #
    # Lowercase
    #
    # Returns the contents of the specified string converted to lowercase.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Lowercase < Choreography

      ####
      #  Create a new instance of the Lowercase Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/Lowercase")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return LowercaseInputSet
      ####
      def new_input_set()
        return LowercaseInputSet.new()
      end

      def make_result_set()
        return LowercaseResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = LowercaseResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Lowercase
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class LowercaseInputSet < Choreography::InputSet

        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, multiline) The text that should be converted to lowercase.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Lowercase Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class LowercaseResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The converted lowercase text.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Lowercase



    ##############################################################################
    #
    # Split
    #
    # Splits a string into sub-strings delimited by the specified delmiter pattern.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Split < Choreography

      ####
      #  Create a new instance of the Split Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/Split")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SplitInputSet
      ####
      def new_input_set()
        return SplitInputSet.new()
      end

      def make_result_set()
        return SplitResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SplitResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Split
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SplitInputSet < Choreography::InputSet

        #### 
        # Set the value of the Delimiter input for this Choreo. 
        # 
        # @param String - (required, string) The delimiter to search for when splitting the string into sub-strings. See Choreo notes for restrictions with delimiters.
        ###

        def set_Delimiter(value)
          set_input("Delimiter", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, multiline) The text that should be split into sub-strings.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Split Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SplitResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) Contains the sub-strings formatted as a JSON array.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Split



    ##############################################################################
    #
    # Substitute
    #
    # Replaces all instances of the specified sub-string within the specified text with a new sub-string. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Substitute < Choreography

      ####
      #  Create a new instance of the Substitute Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/Substitute")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SubstituteInputSet
      ####
      def new_input_set()
        return SubstituteInputSet.new()
      end

      def make_result_set()
        return SubstituteResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SubstituteResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Substitute
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SubstituteInputSet < Choreography::InputSet

        #### 
        # Set the value of the New input for this Choreo. 
        # 
        # @param String - (required, string) New sub-string to replace with.
        ###

        def set_New(value)
          set_input("New", value)
        end
        #### 
        # Set the value of the Old input for this Choreo. 
        # 
        # @param String - (required, string) Old sub-string to replace.
        ###

        def set_Old(value)
          set_input("Old", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) Text to peform substitution.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Substitute Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SubstituteResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The result after the substitution.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Substitute



    ##############################################################################
    #
    # SubstituteRegex
    #
    # Finds all instances of the specified regular expression pattern within the given string and passes the specified new sub-string to the result variable. 
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SubstituteRegex < Choreography

      ####
      #  Create a new instance of the SubstituteRegex Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/SubstituteRegex")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SubstituteRegexInputSet
      ####
      def new_input_set()
        return SubstituteRegexInputSet.new()
      end

      def make_result_set()
        return SubstituteRegexResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SubstituteRegexResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SubstituteRegex
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SubstituteRegexInputSet < Choreography::InputSet

        #### 
        # Set the value of the New input for this Choreo. 
        # 
        # @param String - (required, string) New sub-string to replace with.
        ###

        def set_New(value)
          set_input("New", value)
        end
        #### 
        # Set the value of the Pattern input for this Choreo. 
        # 
        # @param String - (required, string) Regex pattern to use.
        ###

        def set_Pattern(value)
          set_input("Pattern", value)
        end
        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, string) Text to peform substitution.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SubstituteRegex Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SubstituteRegexResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The result after the substitution.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class SubstituteRegex



    ##############################################################################
    #
    # Uppercase
    #
    # Returns the contents of the specified string converted to uppercase.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class Uppercase < Choreography

      ####
      #  Create a new instance of the Uppercase Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Text/Uppercase")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UppercaseInputSet
      ####
      def new_input_set()
        return UppercaseInputSet.new()
      end

      def make_result_set()
        return UppercaseResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UppercaseResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the Uppercase
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UppercaseInputSet < Choreography::InputSet

        #### 
        # Set the value of the Text input for this Choreo. 
        # 
        # @param String - (required, multiline) The text that should be converted to uppercase.
        ###

        def set_Text(value)
          set_input("Text", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the Uppercase Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UppercaseResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Response" output from this Choreo execution
      	#
      	# @return String - (string) The converted uppercase text.
      	####
      	def get_Response()
      	  return @outputs["Response"]
      	end
      end

    end # class Uppercase




  end # module Text

  module TokenStorage



    ##############################################################################
    #
    # DeleteToken
    #
    # Deletes a specified token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DeleteToken < Choreography

      ####
      #  Create a new instance of the DeleteToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/DeleteToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DeleteTokenInputSet
      ####
      def new_input_set()
        return DeleteTokenInputSet.new()
      end

      def make_result_set()
        return DeleteTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DeleteTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DeleteToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DeleteTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to delete.
        ###

        def set_Name(value)
          set_input("Name", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DeleteToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DeleteTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Deleted" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true when token is successfully deleted.
      	####
      	def get_Deleted()
      	  return @outputs["Deleted"]
      	end
      end

    end # class DeleteToken



    ##############################################################################
    #
    # GetTokenDetails
    #
    # Returns one or more tokens represented by a specified list of names.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetTokenDetails < Choreography

      ####
      #  Create a new instance of the GetTokenDetails Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/GetTokenDetails")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetTokenDetailsInputSet
      ####
      def new_input_set()
        return GetTokenDetailsInputSet.new()
      end

      def make_result_set()
        return GetTokenDetailsResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetTokenDetailsResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetTokenDetails
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetTokenDetailsInputSet < Choreography::InputSet

        #### 
        # Set the value of the Names input for this Choreo. 
        # 
        # @param String - (required, json) A list of tokens to return. This should be formated as a JSON array.
        ###

        def set_Names(value)
          set_input("Names", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetTokenDetails Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetTokenDetailsResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Tokens" output from this Choreo execution
      	#
      	# @return String - (json) The token values.
      	####
      	def get_Tokens()
      	  return @outputs["Tokens"]
      	end
      end

    end # class GetTokenDetails



    ##############################################################################
    #
    # IsLocked
    #
    # Returns true or false depending on whether the token is locked or not.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class IsLocked < Choreography

      ####
      #  Create a new instance of the IsLocked Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/IsLocked")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return IsLockedInputSet
      ####
      def new_input_set()
        return IsLockedInputSet.new()
      end

      def make_result_set()
        return IsLockedResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = IsLockedResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the IsLocked
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class IsLockedInputSet < Choreography::InputSet

        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to check.
        ###

        def set_Name(value)
          set_input("Name", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the IsLocked Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class IsLockedResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Locked" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true or false depending on whether the token is locked or not.
      	####
      	def get_Locked()
      	  return @outputs["Locked"]
      	end
      end

    end # class IsLocked



    ##############################################################################
    #
    # IsValid
    #
    # Returns true or false depending on whether the token is valid or not.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class IsValid < Choreography

      ####
      #  Create a new instance of the IsValid Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/IsValid")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return IsValidInputSet
      ####
      def new_input_set()
        return IsValidInputSet.new()
      end

      def make_result_set()
        return IsValidResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = IsValidResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the IsValid
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class IsValidInputSet < Choreography::InputSet

        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to check.
        ###

        def set_Name(value)
          set_input("Name", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the IsValid Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class IsValidResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Valid" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true or false depending on whether the token is valid or not.
      	####
      	def get_Valid()
      	  return @outputs["Valid"]
      	end
      end

    end # class IsValid



    ##############################################################################
    #
    # LockToken
    #
    # Locks a specified token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class LockToken < Choreography

      ####
      #  Create a new instance of the LockToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/LockToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return LockTokenInputSet
      ####
      def new_input_set()
        return LockTokenInputSet.new()
      end

      def make_result_set()
        return LockTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = LockTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the LockToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class LockTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to lock.
        ###

        def set_Name(value)
          set_input("Name", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the LockToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class LockTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Token" output from this Choreo execution
      	#
      	# @return String - (string) When a lock has been obtained, the token value will be returned. If a lock can not be obtained, and empty string is returned.
      	####
      	def get_Token()
      	  return @outputs["Token"]
      	end
      end

    end # class LockToken



    ##############################################################################
    #
    # RetrieveToken
    #
    # Retrieves a specified token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RetrieveToken < Choreography

      ####
      #  Create a new instance of the RetrieveToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/RetrieveToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RetrieveTokenInputSet
      ####
      def new_input_set()
        return RetrieveTokenInputSet.new()
      end

      def make_result_set()
        return RetrieveTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RetrieveTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RetrieveToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RetrieveTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the LockToken input for this Choreo. 
        # 
        # @param Boolean - (optional, boolean) If set to true, the Choreo will attempt to lock the token after retrieving it. If the token is already locked, the Choreo will attempt to get the lock for up-to 1 minute.
        ###

        def set_LockToken(value)
          set_input("LockToken", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to retrieve.
        ###

        def set_Name(value)
          set_input("Name", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RetrieveToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RetrieveTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Token" output from this Choreo execution
      	#
      	# @return String - (string) The token value. This will return an empty string if there is no token or if the token has expired.
      	####
      	def get_Token()
      	  return @outputs["Token"]
      	end
      	####
      	# Retrieve the value for the "Locked" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true or false depending on whether the token is locked or not.
      	####
      	def get_Locked()
      	  return @outputs["Locked"]
      	end
      	####
      	# Retrieve the value for the "Valid" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true or false depending on whether the token is valid or not.
      	####
      	def get_Valid()
      	  return @outputs["Valid"]
      	end
      end

    end # class RetrieveToken



    ##############################################################################
    #
    # SetValid
    #
    # Sets a specified token as valid or invalid.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class SetValid < Choreography

      ####
      #  Create a new instance of the SetValid Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/SetValid")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return SetValidInputSet
      ####
      def new_input_set()
        return SetValidInputSet.new()
      end

      def make_result_set()
        return SetValidResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = SetValidResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the SetValid
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class SetValidInputSet < Choreography::InputSet

        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The name of the token to modify.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the Valid input for this Choreo. 
        # 
        # @param Boolean - (conditional, boolean) Can be set to true or false depending on whether the token is valid or not.
        ###

        def set_Valid(value)
          set_input("Valid", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the SetValid Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class SetValidResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Updated" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true if the operation was successful.
      	####
      	def get_Updated()
      	  return @outputs["Updated"]
      	end
      end

    end # class SetValid



    ##############################################################################
    #
    # StoreToken
    #
    # Stores a token.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class StoreToken < Choreography

      ####
      #  Create a new instance of the StoreToken Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/TokenStorage/StoreToken")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return StoreTokenInputSet
      ####
      def new_input_set()
        return StoreTokenInputSet.new()
      end

      def make_result_set()
        return StoreTokenResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = StoreTokenResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the StoreToken
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class StoreTokenInputSet < Choreography::InputSet

        #### 
        # Set the value of the Expires input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The lifetime of the token (in seconds). Defaults to 0 indicating no expiration.
        ###

        def set_Expires(value)
          set_input("Expires", value)
        end
        #### 
        # Set the value of the Name input for this Choreo. 
        # 
        # @param String - (required, string) The token name. When a token does not exist, it will be inserted. When a token does exist, an update is performed.
        ###

        def set_Name(value)
          set_input("Name", value)
        end
        #### 
        # Set the value of the Value input for this Choreo. 
        # 
        # @param String - (required, string) The token value to store. The maximum number of characters for a token is 4096.
        ###

        def set_Value(value)
          set_input("Value", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the StoreToken Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class StoreTokenResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Updated" output from this Choreo execution
      	#
      	# @return String - (boolean) Returns true if token is stored successfully.
      	####
      	def get_Updated()
      	  return @outputs["Updated"]
      	end
      end

    end # class StoreToken




  end # module TokenStorage

  module Validation



    ##############################################################################
    #
    # CanadianPostalCodes
    #
    # Verifies that a given zip code matches the format expected for Canadian addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class CanadianPostalCodes < Choreography

      ####
      #  Create a new instance of the CanadianPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/CanadianPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return CanadianPostalCodesInputSet
      ####
      def new_input_set()
        return CanadianPostalCodesInputSet.new()
      end

      def make_result_set()
        return CanadianPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = CanadianPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the CanadianPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class CanadianPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the CanadianPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class CanadianPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class CanadianPostalCodes



    ##############################################################################
    #
    # DutchPostalCodes
    #
    # Verifies that a given zip code matches the format expected for Dutch addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class DutchPostalCodes < Choreography

      ####
      #  Create a new instance of the DutchPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/DutchPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return DutchPostalCodesInputSet
      ####
      def new_input_set()
        return DutchPostalCodesInputSet.new()
      end

      def make_result_set()
        return DutchPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = DutchPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the DutchPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class DutchPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the DutchPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class DutchPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class DutchPostalCodes



    ##############################################################################
    #
    # EmailAddress
    #
    # Verifies that a given email address matches an expected standard pattern.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class EmailAddress < Choreography

      ####
      #  Create a new instance of the EmailAddress Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/EmailAddress")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return EmailAddressInputSet
      ####
      def new_input_set()
        return EmailAddressInputSet.new()
      end

      def make_result_set()
        return EmailAddressResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = EmailAddressResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the EmailAddress
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class EmailAddressInputSet < Choreography::InputSet

        #### 
        # Set the value of the EmailAddress input for this Choreo. 
        # 
        # @param String - (required, string) The email address to validate.
        ###

        def set_EmailAddress(value)
          set_input("EmailAddress", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the EmailAddress Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class EmailAddressResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class EmailAddress



    ##############################################################################
    #
    # GermanPostalCodes
    #
    # Verifies that a given zip code matches the format expected for German addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GermanPostalCodes < Choreography

      ####
      #  Create a new instance of the GermanPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/GermanPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GermanPostalCodesInputSet
      ####
      def new_input_set()
        return GermanPostalCodesInputSet.new()
      end

      def make_result_set()
        return GermanPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GermanPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GermanPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GermanPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GermanPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GermanPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class GermanPostalCodes



    ##############################################################################
    #
    # JSON
    #
    # Determines if a specified JSON string is well-formed.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class JSON < Choreography

      ####
      #  Create a new instance of the JSON Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/JSON")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return JSONInputSet
      ####
      def new_input_set()
        return JSONInputSet.new()
      end

      def make_result_set()
        return JSONResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = JSONResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the JSON
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class JSONInputSet < Choreography::InputSet

        #### 
        # Set the value of the JSON input for this Choreo. 
        # 
        # @param String - (required, multiline) The JSON string to validate.
        ###

        def set_JSON(value)
          set_input("JSON", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the JSON Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class JSONResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - (string) The result of the JSON validation. This will return "valid" or "invalid".
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class JSON



    ##############################################################################
    #
    # PasswordCriteria
    #
    # Verifies that a given password matches a standard pattern for passwords.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class PasswordCriteria < Choreography

      ####
      #  Create a new instance of the PasswordCriteria Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/PasswordCriteria")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return PasswordCriteriaInputSet
      ####
      def new_input_set()
        return PasswordCriteriaInputSet.new()
      end

      def make_result_set()
        return PasswordCriteriaResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = PasswordCriteriaResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the PasswordCriteria
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class PasswordCriteriaInputSet < Choreography::InputSet

        #### 
        # Set the value of the MaxLength input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The max length you want to allow for the password. Defaults to 14.
        ###

        def set_MaxLength(value)
          set_input("MaxLength", value)
        end
        #### 
        # Set the value of the MinLength input for this Choreo. 
        # 
        # @param Integer - (optional, integer) The minimum length you want to allow for the password. Defaults to 6.
        ###

        def set_MinLength(value)
          set_input("MinLength", value)
        end
        #### 
        # Set the value of the Password input for this Choreo. 
        # 
        # @param String - (required, string) The password to validate.
        ###

        def set_Password(value)
          set_input("Password", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the PasswordCriteria Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class PasswordCriteriaResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class PasswordCriteria



    ##############################################################################
    #
    # RussianPostalCodes
    #
    # Verifies that a given zip code matches the format expected for Russian addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RussianPostalCodes < Choreography

      ####
      #  Create a new instance of the RussianPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/RussianPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RussianPostalCodesInputSet
      ####
      def new_input_set()
        return RussianPostalCodesInputSet.new()
      end

      def make_result_set()
        return RussianPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RussianPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RussianPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RussianPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RussianPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RussianPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class RussianPostalCodes



    ##############################################################################
    #
    # UKPostalCodes
    #
    # Verifies that a given zip code matches the format expected for UK addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class UKPostalCodes < Choreography

      ####
      #  Create a new instance of the UKPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/UKPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return UKPostalCodesInputSet
      ####
      def new_input_set()
        return UKPostalCodesInputSet.new()
      end

      def make_result_set()
        return UKPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = UKPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the UKPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class UKPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate. Letters must be in uppercase to be valid.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the UKPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class UKPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match -- "valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class UKPostalCodes



    ##############################################################################
    #
    # USPostalCodes
    #
    # Verifies that a given zip code matches the format expected for US addresses.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class USPostalCodes < Choreography

      ####
      #  Create a new instance of the USPostalCodes Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/USPostalCodes")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return USPostalCodesInputSet
      ####
      def new_input_set()
        return USPostalCodesInputSet.new()
      end

      def make_result_set()
        return USPostalCodesResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = USPostalCodesResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the USPostalCodes
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class USPostalCodesInputSet < Choreography::InputSet

        #### 
        # Set the value of the ZipCode input for this Choreo. 
        # 
        # @param String - (required, string) The zip code to validate.
        ###

        def set_ZipCode(value)
          set_input("ZipCode", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the USPostalCodes Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class USPostalCodesResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Match" output from this Choreo execution
      	#
      	# @return String - (string) Contains a string indicating the result of the match --"valid" or "invalid".
      	####
      	def get_Match()
      	  return @outputs["Match"]
      	end
      end

    end # class USPostalCodes



    ##############################################################################
    #
    # XML
    #
    # Validates XML for basic well-formedness and allows you to check XML against a specified XSD schema file.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class XML < Choreography

      ####
      #  Create a new instance of the XML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/Validation/XML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return XMLInputSet
      ####
      def new_input_set()
        return XMLInputSet.new()
      end

      def make_result_set()
        return XMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = XMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the XML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class XMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the XMLFile input for this Choreo. 
        # 
        # @param String - (required, xml) The XML file you want to validate.
        ###

        def set_XMLFile(value)
          set_input("XMLFile", value)
        end
        #### 
        # Set the value of the XSDFile input for this Choreo. 
        # 
        # @param String - (optional, xml) The XSD file to validate an XML file against.
        ###

        def set_XSDFile(value)
          set_input("XSDFile", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the XML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class XMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Error" output from this Choreo execution
      	#
      	# @return String - (string) The error description that is generated if a validation error occurs.
      	####
      	def get_Error()
      	  return @outputs["Error"]
      	end
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - (string) The result of the validation. Returns the string "valid" or "invalid".
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class XML




  end # module Validation

  module XML



    ##############################################################################
    #
    # GetValuesFromXML
    #
    # Returns all element or attribute values with a specified name.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class GetValuesFromXML < Choreography

      ####
      #  Create a new instance of the GetValuesFromXML Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/XML/GetValuesFromXML")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return GetValuesFromXMLInputSet
      ####
      def new_input_set()
        return GetValuesFromXMLInputSet.new()
      end

      def make_result_set()
        return GetValuesFromXMLResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = GetValuesFromXMLResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the GetValuesFromXML
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class GetValuesFromXMLInputSet < Choreography::InputSet

        #### 
        # Set the value of the Node input for this Choreo. 
        # 
        # @param String - (required, string) The name of the element or attribute that contains the values you want to return. Note that attribute names should be preceded with an "@" sign (e.g. @name).
        ###

        def set_Node(value)
          set_input("Node", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json or csv.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML that contains the elements or attributes you want to retrieve.
        ###

        def set_XML(value)
          set_input("XML", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the GetValuesFromXML Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class GetValuesFromXMLResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - The element or attribute values.
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class GetValuesFromXML



    ##############################################################################
    #
    # RunXPathQuery
    #
    # Executes an XPath query against a specified XML file and returns the result in CSV or JSON format.
    #
    # Copyright 2014, Temboo Inc.
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    # http://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing,
    # software distributed under the License is distributed on an
    # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
    # either express or implied. See the License for the specific
    # language governing permissions and limitations under the License.
    #
    ##############################################################################

    class RunXPathQuery < Choreography

      ####
      #  Create a new instance of the RunXPathQuery Choreo. A TembooSession object, containing a valid
      #  set of Temboo credentials, must be supplied.
      ####
      def initialize(session)
        super(session, "/Library/Utilities/XML/RunXPathQuery")
      end

      #### 
      # Obtain an InputSet object, used to define inputs for an execution of this Choreo.
      #
      # @return RunXPathQueryInputSet
      ####
      def new_input_set()
        return RunXPathQueryInputSet.new()
      end

      def make_result_set()
        return RunXPathQueryResultSet.new()
      end

      ####
      # Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
      # and return a ResultSet containing the execution results.
      # @param choreoInputs
      # @return
      # @throws TembooException
      ####
      def execute(input_set = nil)
        resp = super(input_set)
        results = RunXPathQueryResultSet.new(resp)
        return results
      end

      ####
      # An InputSet with methods appropriate for specifying the inputs to the RunXPathQuery
      # Choreo. The InputSet object is used to specify input parameters when executing this Choreo.
      ####
      class RunXPathQueryInputSet < Choreography::InputSet

        #### 
        # Set the value of the Mode input for this Choreo. 
        # 
        # @param String - (conditional, string) Valid values are "select" (the default) or "recursive". Recursive mode will iterate using the provided XPath. Select mode will return the first match if there are multiple rows in the XML provided.
        ###

        def set_Mode(value)
          set_input("Mode", value)
        end
        #### 
        # Set the value of the ResponseFormat input for this Choreo. 
        # 
        # @param String - (optional, string) The format that the response should be in. Valid values are: json or csv.
        ###

        def set_ResponseFormat(value)
          set_input("ResponseFormat", value)
        end
        #### 
        # Set the value of the XML input for this Choreo. 
        # 
        # @param String - (required, xml) The XML that contains the elements or attributes you want to retrieve.
        ###

        def set_XML(value)
          set_input("XML", value)
        end
        #### 
        # Set the value of the XPath input for this Choreo. 
        # 
        # @param String - (required, string) The XPath query to run.
        ###

        def set_XPath(value)
          set_input("XPath", value)
        end

      end

      ####
      # A ResultSet with methods tailored to the values returned by the RunXPathQuery Choreo.
      # The ResultSet object is used to retrieve the results of a Choreo execution.
      ####
      class RunXPathQueryResultSet < Choreography::ResultSet
      	####
      	# Retrieve the value for the "Result" output from this Choreo execution
      	#
      	# @return String - The XPath query result.
      	####
      	def get_Result()
      	  return @outputs["Result"]
      	end
      end

    end # class RunXPathQuery




  end # module XML

end # module Utilities